@@ -17,8 +17,8 @@ mkdir MediaInfo_Lib_GNU_FromSource
 #-----------------------------------------------------------------------
 # Preparing : Project
 cd ../Project/GNU/Library
-chmod u+x autogen
-./autogen
+chmod u+x autogen.sh
+./autogen.sh
 cd ../../../Release
 
 
@@ -26,7 +26,7 @@ cd ../../../Release
 # Copying : Project
 mkdir -p MediaInfo_Lib_GNU_FromSource/Project/GNU/Library
 cp ../Project/GNU/Library/aclocal.m4 MediaInfo_Lib_GNU_FromSource/Project/GNU/Library/
-cp ../Project/GNU/Library/autogen MediaInfo_Lib_GNU_FromSource/Project/GNU/Library/
+cp ../Project/GNU/Library/autogen.sh MediaInfo_Lib_GNU_FromSource/Project/GNU/Library/
 cp ../Project/GNU/Library/config.guess MediaInfo_Lib_GNU_FromSource/Project/GNU/Library/
 cp ../Project/GNU/Library/config.sub MediaInfo_Lib_GNU_FromSource/Project/GNU/Library/
 cp ../Project/GNU/Library/configure MediaInfo_Lib_GNU_FromSource/Project/GNU/Library/
@@ -48,9 +48,18 @@ cp -r ../Source/ThirdParty/aes-gladman/*.h MediaInfo_Lib_GNU_FromSource/Source/T
 cp -r ../Source/ThirdParty/aes-gladman/*.c MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/aes-gladman/
 mkdir -p MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/base64
 cp -r ../Source/ThirdParty/base64/*.h MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/base64/
+mkdir -p MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/hmac-gladman
+cp -r ../Source/ThirdParty/hmac-gladman/*.h MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/hmac-gladman/
+cp -r ../Source/ThirdParty/hmac-gladman/*.c MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/hmac-gladman/
 mkdir -p MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/md5
 cp -r ../Source/ThirdParty/md5/*.h MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/md5/
 cp -r ../Source/ThirdParty/md5/*.c MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/md5/
+mkdir -p MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/sha1-gladman
+cp -r ../Source/ThirdParty/sha1-gladman/*.h MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/sha1-gladman/
+cp -r ../Source/ThirdParty/sha1-gladman/*.c MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/sha1-gladman/
+mkdir -p MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/sha2-gladman
+cp -r ../Source/ThirdParty/sha2-gladman/*.h MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/sha2-gladman/
+cp -r ../Source/ThirdParty/sha2-gladman/*.c MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/sha2-gladman/
 mkdir -p MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/tinyxml2
 cp -r ../Source/ThirdParty/tinyxml2/*.h MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/tinyxml2/
 cp -r ../Source/ThirdParty/tinyxml2/*.cpp MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/tinyxml2/
