@@ -254,6 +254,7 @@ void File_Aac::AudioSpecificConfig (size_t End)
     bool    sbrData=false, sbrPresentFlag=false, psData=false, psPresentFlag=false;
     Element_Begin1("AudioSpecificConfig");
     GetAudioObjectType(audioObjectType,                         "audioObjectType");
+    Infos["CodecID"].From_Number(audioObjectType);
     Get_S1 (4, sampling_frequency_index,                        "samplingFrequencyIndex"); Param_Info1(Aac_sampling_frequency[sampling_frequency_index]);
     if (sampling_frequency_index==0xF)
     {
@@ -433,7 +434,7 @@ void File_Aac::AudioSpecificConfig (size_t End)
                     }
                     else
                         extension_sampling_frequency=Aac_sampling_frequency[extension_sampling_frequency_index];
-                    if (End!=(size_t)-1 && Data_BS_Remain()>=End+12)
+                    if (Data_BS_Remain()>=End+12)
                     {
                         int16u syncExtensionType;
                         Get_S2(11,syncExtensionType,            "syncExtensionType");
@@ -445,7 +446,7 @@ void File_Aac::AudioSpecificConfig (size_t End)
                     }
                 }
             }
-            if ( extensionAudioObjectType == 22 )
+            if ( extensionAudioObjectType == 29 )
             {
                 Get_SB(sbrPresentFlag,                          "sbrPresentFlag");
                 if (sbrPresentFlag)
@@ -490,20 +491,22 @@ void File_Aac::AudioSpecificConfig_OutOfBand (int64s sampling_frequency_, int8u
     {
         if (audioObjectType==(int8u)-1)
             return; //All data is not yet available
-        if (Infos.find("Format_Settings_SBR")!=Infos.end())
+        std::map<std::string, Ztring>::const_iterator i=Infos.find("Format_Settings_SBR");
+        if (i!=Infos.end())
         {
             sbrData=true;
-            sbrPresentFlag=Infos["Format_Settings_SBR"].find(__T("Yes"))!=string::npos;
+            sbrPresentFlag=i->second.find(__T("Yes"))!=string::npos;
         }
         else
         {
             sbrData=false;
             sbrPresentFlag=false;
         }
-        if (Infos.find("Format_Settings_PS")!=Infos.end())
+        i = Infos.find("Format_Settings_PS");
+        if (i!=Infos.end())
         {
             psData=true;
-            psPresentFlag=Infos["Format_Settings_PS"].find(__T("Yes"))!=string::npos;
+            psPresentFlag=i->second.find(__T("Yes"))!=string::npos;
         }
         else
         {
@@ -530,10 +533,10 @@ void File_Aac::AudioSpecificConfig_OutOfBand (int64s sampling_frequency_, int8u
     if (sbrPresentFlag || !Infos["Format_Settings_SBR"].empty())
     {
         Infos["Format_Profile"]=__T("HE-AAC");
-        Ztring SamplingRate_Previous=Infos["SamplingRate"];
         int32u SamplingRate=(extension_sampling_frequency_index==(int8u)-1)?(((int32u)Frequency_b)*2):extension_sampling_frequency;
         if (SamplingRate)
         {
+            const Ztring SamplingRate_Previous = Infos["SamplingRate"];
             Infos["SamplingRate"].From_Number(SamplingRate, 10);
             if (MediaInfoLib::Config.LegacyStreamDisplay_Get())
             {
@@ -541,36 +544,15 @@ void File_Aac::AudioSpecificConfig_OutOfBand (int64s sampling_frequency_, int8u
                 Infos["SamplingRate"]+=__T(" / ")+SamplingRate_Previous;
             }
         }
-        Infos["Format_Settings_SBR"]=__T("Yes (Implicit)");
+        Infos["Format_Settings"]=sbrData?__T("Explicit"):__T("NBC"); // "Not Backward Compatible"
+        Infos["Format_Settings_SBR"]=sbrData?__T("Yes (Explicit)"):__T("Yes (NBC)"); // "Not Backward Compatible"
         Infos["Codec"]=Ztring().From_Local(Aac_audioObjectType(audioObjectType))+__T("-SBR");
     }
     else if (sbrData)
         Infos["Format_Settings_SBR"]=__T("No (Explicit)");
 
     if (psPresentFlag || !Infos["Format_Settings_PS"].empty())
-    {
-        Infos["Format_Profile"]=__T("HE-AACv2");
-        Ztring Channels=Infos["Channel(s)"];
-        Ztring ChannelPositions=Infos["ChannelPositions"];
-        Ztring SamplingRate_Previous=Infos["SamplingRate"];
-        Infos["Channel(s)"]=__T("2");
-        Infos["ChannelPositions"]=__T("Front: L R");
-        if (MediaInfoLib::Config.LegacyStreamDisplay_Get())
-        {
-            Infos["Format_Profile"]+=__T(" / HE-AAC / LC");
-            Infos["Channel(s)"]+=__T(" / ")+Channels+__T(" / ")+Channels;
-            Infos["ChannelPositions"]+=__T(" / ")+ChannelPositions+__T(" / ")+ChannelPositions;
-            int32u SamplingRate=(extension_sampling_frequency_index==(int8u)-1)?(((int32u)Frequency_b)*2):extension_sampling_frequency;
-            if (SamplingRate)
-                Infos["SamplingRate"]=Ztring().From_Number(SamplingRate, 10)+__T(" / ")+SamplingRate_Previous;
-        }
-        Infos["Format_Settings_PS"]=__T("Yes (Implicit)");
-        if (StreamPos_Last!=(size_t)-1)
-        {
-            Ztring Codec=Retrieve(Stream_Audio, StreamPos_Last, Audio_Codec);
-            Infos["Codec"]=Ztring().From_Local(Aac_audioObjectType(audioObjectType))+__T("-SBR-PS");
-        }
-    }
+        FillInfosHEAACv2(psData ? __T("Explicit") : __T("NBC")); // "Not Backward Compatible");
     else if (psData)
         Infos["Format_Settings_PS"]=__T("No (Explicit)");
 }
