@@ -23,6 +23,7 @@
 //---------------------------------------------------------------------------
 #include "MediaInfo/Export/Export_Mpeg7.h"
 #include "MediaInfo/File__Analyse_Automatic.h"
+#include "MediaInfo/OutputHelpers.h"
 #include <ctime>
 using namespace std;
 //---------------------------------------------------------------------------
@@ -84,7 +85,7 @@ const Char* Mpeg7_Type(MediaInfo_Internal &MI) //TO ADAPT
         return __T("Video");
     if (Format==__T("MPEG Audio") || Format==__T("Wave"))
         return __T("Audio");
-    if (Format==__T("BMP") || Format==__T("GIF") || Format==__T("JPEG") || Format==__T("JPEG 2000") || Format==__T("JPEG 2000") || Format==__T("PNG") || Format==__T("TIFF"))
+    if (Format==__T("BMP") || Format==__T("GIF") || Format==__T("JPEG") || Format==__T("JPEG 2000") || Format==__T("PNG") || Format==__T("TIFF"))
         return __T("Image");
     return __T("Multimedia");
 }
@@ -115,7 +116,7 @@ int32u Mpeg7_ContentCS_termID(MediaInfo_Internal &MI)
         return 40200;
     if (Format==__T("MPEG Audio") || Format==__T("Wave"))
         return 10000;
-    if (Format==__T("BMP") || Format==__T("GIF") || Format==__T("JPEG") || Format==__T("JPEG 2000") || Format==__T("JPEG 2000") || Format==__T("PNG") || Format==__T("TIFF"))
+    if (Format==__T("BMP") || Format==__T("GIF") || Format==__T("JPEG") || Format==__T("JPEG 2000") || Format==__T("PNG") || Format==__T("TIFF"))
         return 40100;
     return 500000;
 }
@@ -145,9 +146,9 @@ int32u Mpeg7_FileFormatCS_termID_MediaInfo(MediaInfo_Internal &MI)
 
     if (Format==__T("MPEG Audio"))
     {
-        if (MI.Get(Stream_Audio, 0, Audio_Format_Profile).find(__T("2"))!=string::npos)
+        if (MI.Get(Stream_Audio, 0, Audio_Format_Profile).find(__T('2'))!=string::npos)
             return 500000; //mp2
-        if (MI.Get(Stream_Audio, 0, Audio_Format_Profile).find(__T("1"))!=string::npos)
+        if (MI.Get(Stream_Audio, 0, Audio_Format_Profile).find(__T('1'))!=string::npos)
             return 510000; //mp1
         return 0;
     }
@@ -173,10 +174,10 @@ int32u Mpeg7_FileFormatCS_termID(MediaInfo_Internal &MI)
         return 60000;
     if (Format==__T("JPEG"))
         return 10000;
-    if (Format==__T("JPEG 2000") || Format==__T("JPEG 2000"))
+    if (Format==__T("JPEG 2000"))
         return 20000;
     if (Format==__T("MPEG Audio"))
-        return (MI.Get(Stream_Audio, 0, Audio_Format_Profile).find(__T("3"))!=string::npos)?40000:0;
+        return (MI.Get(Stream_Audio, 0, Audio_Format_Profile).find(__T('3'))!=string::npos)?40000:0;
     if (Format==__T("MPEG-4"))
         return 50000;
     if (Format==__T("MPEG-PS"))
@@ -254,9 +255,9 @@ int32u Mpeg7_VisualCodingFormatCS_termID(MediaInfo_Internal &MI, size_t StreamPo
 
     if (Format==__T("MPEG Video"))
     {
-        if (Version.find(__T("1"))!=string::npos)
+        if (Version.find(__T('1'))!=string::npos)
             return 10000;
-        if (Version.find(__T("2"))!=string::npos)
+        if (Version.find(__T('2'))!=string::npos)
         {
             if (Profile.find(__T("Simple@"))!=string::npos)
             {
@@ -538,204 +539,6 @@ int32u Mpeg7_VisualCodingFormatCS_termID(MediaInfo_Internal &MI, size_t StreamPo
     return 0;
 }
 
-Ztring Mpeg7_VisualCodingFormatCS_Name(int32u termID, MediaInfo_Internal &MI, size_t StreamPos) //xxyyzz: xx=main number, yy=sub-number, zz=sub-sub-number
-{
-    switch (termID/10000)
-    {
-        case 1 : return __T("MPEG-1 Video");
-        case 2 :    switch ((termID%10000)/100)
-                    {
-                        case 1 :    switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-2 Video Simple Profile @ Main Level");
-                                        default: return __T("MPEG-2 Video Simple Profile");
-                                    }
-                        case 2 :    switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-2 Video Main Profile @ Low Level");
-                                        case 2 : return __T("MPEG-2 Video Main Profile @ Main Level");
-                                        case 3 : return __T("MPEG-2 Video Main Profile @ High 1440 Level");
-                                        case 4 : return __T("MPEG-2 Video Main Profile @ High Level");
-                                        default: return __T("MPEG-2 Video Main Profile");
-                                    }
-                        case 3 :    switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-2 Video SNR Scalable Profile @ Low Level");
-                                        case 2 : return __T("MPEG-2 Video SNR Scalable Profile @ Main Level");
-                                        default: return __T("MPEG-2 Video SNR Scalable Profile");
-                                    }
-                        case 4 :    switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-2 Video Spatial Scalable Profile @ Main Level");
-                                        case 2 : return __T("MPEG-2 Video Spatial Scalable Profile @ High 1440 Level");
-                                        case 3 : return __T("MPEG-2 Video Spatial Scalable Profile @ High Level");
-                                        default: return __T("MPEG-2 Video Spatial Scalable Profile");
-                                    }
-                        case 5 :    switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-2 Video High Profile @ Main Level");
-                                        case 2 : return __T("MPEG-2 Video High Profile @ High 1440 Level");
-                                        case 3 : return __T("MPEG-2 Video High Profile @ High Level");
-                                        default: return __T("MPEG-2 Video High Profile");
-                                    }
-                        case 6 :    switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-2 Video Multiview Profile @ Main Level");
-                                        default: return __T("MPEG-2 Video Multiview Profile");
-                                    }
-                        case 7 :    switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-2 Video 4:2:2 Profile @ Main Level");
-                                        default: return __T("MPEG-2 Video 4:2:2 Profile");
-                                    }
-                        default: return __T("MPEG-2 Video");
-                    }
-        case 3 :    switch ((termID%10000)/100)
-                    {
-                        case  1 :   switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-4 Visual Simple Profile @ Level 0");
-                                        case 2 : return __T("MPEG-4 Visual Simple Profile @ Level 1");
-                                        case 3 : return __T("MPEG-4 Visual Simple Profile @ Level 2");
-                                        case 4 : return __T("MPEG-4 Visual Simple Profile @ Level 3");
-                                        default: return __T("MPEG-4 Visual Simple Profile");
-                                    }
-                        case  2 :   switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-4 Visual Simple Scalable Profile @ Level 1");
-                                        case 2 : return __T("MPEG-4 Visual Simple Scalable Profile @ Level 2");
-                                        default: return __T("MPEG-4 Visual Simple Scalable Profile");
-                                    }
-                        case  3 :   switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-4 Advanced Visual Simple Profile @ Level 0");
-                                        case 2 : return __T("MPEG-4 Advanced Visual Simple Profile @ Level 1");
-                                        case 3 : return __T("MPEG-4 Advanced Visual Simple Profile @ Level 2");
-                                        case 4 : return __T("MPEG-4 Advanced Visual Simple Profile @ Level 3");
-                                        case 5 : return __T("MPEG-4 Advanced Visual Simple Profile @ Level 4");
-                                        case 6 : return __T("MPEG-4 Advanced Visual Simple Profile @ Level 5");
-                                        default: return __T("MPEG-4 Advanced Visual Simple Profile");
-                                    }
-                        case  4 :   switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-4 Visual Core Profile @ Level 1");
-                                        case 2 : return __T("MPEG-4 Visual Core Profile @ Level 2");
-                                        default: return __T("MPEG-4 Visual Core Profile");
-                                    }
-                        case  5 :   switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-4 Visual Core-Scalable Profile @ Level 1");
-                                        case 2 : return __T("MPEG-4 Visual Core-Scalable Profile @ Level 2");
-                                        case 3 : return __T("MPEG-4 Visual Core-Scalable Profile @ Level 3");
-                                        default: return __T("MPEG-4 Visual Core-Scalable Profile");
-                                    }
-                        case  6 :   switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-4 Visual AdvancedCore Profile @ Level 1");
-                                        case 2 : return __T("MPEG-4 Visual AdvancedCore Profile @ Level 2");
-                                        default: return __T("MPEG-4 Visual AdvancedCore Profile");
-                                    }
-                        case  7 :   switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-4 Visual Main Profile @ Level 2");
-                                        case 2 : return __T("MPEG-4 Visual Main Profile @ Level 3");
-                                        case 3 : return __T("MPEG-4 Visual Main Profile @ Level 4");
-                                        default: return __T("MPEG-4 Visual Main Profile");
-                                    }
-                        case  8 :   switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-4 Visual N-bit Profile @ Level 2");
-                                        default: return __T("MPEG-4 Visual Main Profile");
-                                    }
-                        case  9 :   switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-4 Visual Advanced Real Time Simple Profile @ Level 1");
-                                        case 2 : return __T("MPEG-4 Visual Advanced Real Time Simple Profile @ Level 2");
-                                        case 3 : return __T("MPEG-4 Visual Advanced Real Time Simple Profile @ Level 3");
-                                        case 4 : return __T("MPEG-4 Visual Advanced Real Time Simple Profile @ Level 4");
-                                        default: return __T("MPEG-4 Visual Advanced Real Time Simple Profile");
-                                    }
-                        case 10 :   switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-4 Visual Advanced Coding Efficiency Profile @ Level 1");
-                                        case 2 : return __T("MPEG-4 Visual Advanced Coding Efficiency Profile @ Level 2");
-                                        case 3 : return __T("MPEG-4 Visual Advanced Coding Efficiency Profile @ Level 3");
-                                        case 4 : return __T("MPEG-4 Visual Advanced Coding Efficiency Profile @ Level 4");
-                                        default: return __T("MPEG-4 Visual Advanced Coding Efficiency Profile");
-                                    }
-                        case 11 :   switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-4 Visual Simple Studio Profile @ Level 1");
-                                        case 2 : return __T("MPEG-4 Visual Simple Studio Profile @ Level 2");
-                                        case 3 : return __T("MPEG-4 Visual Simple Studio Profile @ Level 3");
-                                        case 4 : return __T("MPEG-4 Visual Simple Studio Profile @ Level 4");
-                                        default: return __T("MPEG-4 Visual Simple Studio Profile");
-                                    }
-                        case 12 :   switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-4 Visual Core Studio Profile @ Level 1");
-                                        case 2 : return __T("MPEG-4 Visual Core Studio Profile @ Level 2");
-                                        case 3 : return __T("MPEG-4 Visual Core Studio Profile @ Level 3");
-                                        case 4 : return __T("MPEG-4 Visual Core Studio Profile @ Level 4");
-                                        default: return __T("MPEG-4 Visual Core Studio Profile");
-                                    }
-                        case 13 :   switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-4 Visual Fine Granularity Scalable Profile @ Level 0");
-                                        case 2 : return __T("MPEG-4 Visual Fine Granularity Scalable Profile @ Level 1");
-                                        case 3 : return __T("MPEG-4 Visual Fine Granularity Scalable Profile @ Level 2");
-                                        case 4 : return __T("MPEG-4 Visual Fine Granularity Scalable Profile @ Level 3");
-                                        case 5 : return __T("MPEG-4 Visual Fine Granularity Scalable Profile @ Level 4");
-                                        case 6 : return __T("MPEG-4 Visual Fine Granularity Scalable Profile @ Level 5");
-                                        default: return __T("MPEG-4 Visual Fine Granularity Scalable Profile");
-                                    }
-                        case 14 :   switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-4 Simple Face Animation Profile @ Level 1");
-                                        case 2 : return __T("MPEG-4 Simple Face Animation Profile @ Level 2");
-                                        default: return __T("MPEG-4 Simple Face Animation Profile");
-                                    }
-                        case 15 :   switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-4 Simple FBA Profile @ Level 1");
-                                        case 2 : return __T("MPEG-4 Simple FBA Profile @ Level 2");
-                                        default: return __T("MPEG-4 Simple FBA Profile");
-                                    }
-                        case 16 :   switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-4 Basic Animated Texture Profile @ Level 1");
-                                        case 2 : return __T("MPEG-4 Basic Animated Texture Profile @ Level 2");
-                                        default: return __T("MPEG-4 Basic Animated Texture Profile");
-                                    }
-                        case 17 :   switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-4 Advanced Scalable Texture Profile @ Level 1");
-                                        default: return __T("MPEG-4 Advanced Scalable Texture Profile");
-                                    }
-                        case 18 :   switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-4 Visual Advanced Scalable Texture Profile @ Level 1");
-                                        case 2 : return __T("MPEG-4 Visual Advanced Scalable Texture Profile @ Level 2");
-                                        case 3 : return __T("MPEG-4 Visual Advanced Scalable Texture Profile @ Level 3");
-                                        default: return __T("MPEG-4 Visual Advanced Scalable Texture Profile");
-                                    }
-                        case 19 :   switch (termID%100)
-                                    {
-                                        case 1 : return __T("MPEG-4 Visual Hybrid Profile @ Level 1");
-                                        case 2 : return __T("MPEG-4 Visual Hybrid Profile @ Level 2");
-                                        default: return __T("MPEG-4 Visual Hybrid Profile");
-                                    }
-                        default: return __T("MPEG-4 Visual");
-                    }
-        case 4 :    return __T("JPEG");
-        case 5 :    return __T("MJPEG");
-        case 6 :    return __T("JPEG2000");
-        case 7 :    return __T("H261");
-        case 8 :    return __T("H263");
-        default: return MI.Get(Stream_Video, StreamPos, Video_Format);
-    }
-}
-
 //---------------------------------------------------------------------------
 Ztring Mpeg7_Visual_colorDomain(MediaInfo_Internal &MI, size_t StreamPos)
 {
@@ -783,23 +586,23 @@ int32u Mpeg7_AudioCodingFormatCS_termID(MediaInfo_Internal &MI, size_t StreamPos
         return 20000;
     if (Format==__T("MPEG Audio"))
     {
-        if (Version.find(__T("1"))!=string::npos)
+        if (Version.find(__T('1'))!=string::npos)
         {
-            if (Profile.find(__T("1"))!=string::npos)
+            if (Profile.find(__T('1'))!=string::npos)
                 return 30100;
-            if (Profile.find(__T("2"))!=string::npos)
+            if (Profile.find(__T('2'))!=string::npos)
                 return 30200;
-            if (Profile.find(__T("3"))!=string::npos)
+            if (Profile.find(__T('3'))!=string::npos)
                 return 30300;
             return 30000;
         }
-        if (Version.find(__T("2"))!=string::npos)
+        if (Version.find(__T('2'))!=string::npos)
         {
-            if (Profile.find(__T("1"))!=string::npos)
+            if (Profile.find(__T('1'))!=string::npos)
                 return 40100;
-            if (Profile.find(__T("2"))!=string::npos)
+            if (Profile.find(__T('2'))!=string::npos)
                 return 40200;
-            if (Profile.find(__T("3"))!=string::npos)
+            if (Profile.find(__T('3'))!=string::npos)
                 return 40300;
             return 40000;
         }
@@ -1053,7 +856,7 @@ Ztring Mpeg7_Transform_Visual(Ztring &ToReturn, MediaInfo_Internal &MI, size_t S
     }
     ToReturn+=Mpeg7_Visual_colorDomain(MI, StreamPos); //Algo puts empty string if not known
     ToReturn+=__T(">\n");
-    ToReturn+=__T("\t\t\t\t\t\t\t\t\t<mpeg7:Name xml:lang=\"en\">"); ToReturn+=Mpeg7_VisualCodingFormatCS_Name((VisualCodingFormatCS_termID/10000)*10000, MI, StreamPos); ToReturn+=__T("</mpeg7:Name>\n");
+    ToReturn+=__T("\t\t\t\t\t\t\t\t\t<mpeg7:Name xml:lang=\"en\">"); ToReturn+=VideoCompressionCodeCS_Name((VisualCodingFormatCS_termID/10000)*10000, MI, StreamPos); ToReturn+=__T("</mpeg7:Name>\n");
     if (VisualCodingFormatCS_termID%10000)
     {
         ToReturn+=__T("\t\t\t\t\t\t\t\t\t<mpeg7:Term termID=\"");
@@ -1061,7 +864,7 @@ Ztring Mpeg7_Transform_Visual(Ztring &ToReturn, MediaInfo_Internal &MI, size_t S
         ToReturn+=__T(".");
         ToReturn+=Ztring::ToZtring((VisualCodingFormatCS_termID%10000)/100);
         ToReturn+=__T("\">\n");
-        ToReturn+=__T("\t\t\t\t\t\t\t\t\t\t<mpeg7:Name xml:lang=\"en\">"); ToReturn+=Mpeg7_VisualCodingFormatCS_Name((VisualCodingFormatCS_termID/100)*100, MI, StreamPos); ToReturn+=__T("</mpeg7:Name>\n");
+        ToReturn+=__T("\t\t\t\t\t\t\t\t\t\t<mpeg7:Name xml:lang=\"en\">"); ToReturn+=VideoCompressionCodeCS_Name((VisualCodingFormatCS_termID/100)*100, MI, StreamPos); ToReturn+=__T("</mpeg7:Name>\n");
         if (VisualCodingFormatCS_termID%100)
         {
             ToReturn+=__T("\t\t\t\t\t\t\t\t\t\t<mpeg7:Term termID=\"");
@@ -1071,7 +874,7 @@ Ztring Mpeg7_Transform_Visual(Ztring &ToReturn, MediaInfo_Internal &MI, size_t S
             ToReturn+=__T(".");
             ToReturn+=Ztring::ToZtring(VisualCodingFormatCS_termID%100);
             ToReturn+=__T("\">\n");
-            ToReturn+=__T("\t\t\t\t\t\t\t\t\t\t\t<mpeg7:Name xml:lang=\"en\">"); ToReturn+=Mpeg7_VisualCodingFormatCS_Name(VisualCodingFormatCS_termID, MI, StreamPos); ToReturn+=__T("</mpeg7:Name>\n");
+            ToReturn+=__T("\t\t\t\t\t\t\t\t\t\t\t<mpeg7:Name xml:lang=\"en\">"); ToReturn+=VideoCompressionCodeCS_Name(VisualCodingFormatCS_termID, MI, StreamPos); ToReturn+=__T("</mpeg7:Name>\n");
             ToReturn+=__T("\t\t\t\t\t\t\t\t\t\t</mpeg7:Term>\n");
         }
         ToReturn+=__T("\t\t\t\t\t\t\t\t\t</mpeg7:Term>\n");
