@@ -29,6 +29,8 @@ enum generic
     Generic_Format_Commercial_IfAny,
     Generic_Format_Version,
     Generic_Format_Profile,
+    Generic_Format_Level,
+    Generic_Format_Tier,
     Generic_Format_Compression,
     Generic_Format_Settings,
     Generic_InternetMediaType,
@@ -217,6 +219,7 @@ enum general
     General_Format_Commercial_IfAny,
     General_Format_Version,
     General_Format_Profile,
+    General_Format_Level,
     General_Format_Compression,
     General_Format_Settings,
     General_InternetMediaType,
@@ -306,6 +309,9 @@ enum general
     General_Encryption_Mode,
     General_Encryption_Padding,
     General_Encryption_InitializationVector,
+    General_UniversalAdID_String,
+    General_UniversalAdID_Registry,
+    General_UniversalAdID_Value,
     General_Title,
     General_Title_More,
     General_Title_Url,
@@ -353,6 +359,7 @@ enum general
     General_Accompaniment,
     General_Composer,
     General_Composer_Nationality,
+    General_Composer_Sort,
     General_Arranger,
     General_Lyricist,
     General_Original_Lyricist,
@@ -387,6 +394,7 @@ enum general
     General_Publisher_URL,
     General_Label,
     General_Genre,
+    General_PodcastCategory,
     General_Mood,
     General_ContentType,
     General_Subject,
@@ -453,7 +461,7 @@ enum general
     General_ServiceChannel,
     General_Service_Url,
     General_ServiceProvider,
-    General_ServiceProviderr_Url,
+    General_ServiceProvider_Url,
     General_ServiceType,
     General_NetworkName,
     General_OriginalNetworkName,
@@ -503,10 +511,16 @@ enum video
     Video_Format_Commercial_IfAny,
     Video_Format_Version,
     Video_Format_Profile,
+    Video_Format_Level,
+    Video_Format_Tier,
     Video_Format_Compression,
     Video_MultiView_BaseProfile,
     Video_MultiView_Count,
     Video_MultiView_Layout,
+    Video_DolbyVision_String,
+    Video_DolbyVision_Version,
+    Video_DolbyVision_Profile,
+    Video_DolbyVision_Layers,
     Video_Format_Settings,
     Video_Format_Settings_BVOP,
     Video_Format_Settings_BVOP_String,
@@ -791,6 +805,8 @@ enum video
     Video_Language_String3,
     Video_Language_String4,
     Video_Language_More,
+    Video_ServiceKind,
+    Video_ServiceKind_String,
     Video_Disabled,
     Video_Disabled_String,
     Video_Default,
@@ -842,6 +858,7 @@ enum audio
     Audio_Format_Commercial_IfAny,
     Audio_Format_Version,
     Audio_Format_Profile,
+    Audio_Format_Level,
     Audio_Format_Compression,
     Audio_Format_Settings,
     Audio_Format_Settings_SBR,
@@ -1078,6 +1095,8 @@ enum audio
     Audio_Language_String3,
     Audio_Language_String4,
     Audio_Language_More,
+    Audio_ServiceKind,
+    Audio_ServiceKind_String,
     Audio_Disabled,
     Audio_Disabled_String,
     Audio_Default,
@@ -1316,6 +1335,8 @@ enum text
     Text_Language_String3,
     Text_Language_String4,
     Text_Language_More,
+    Text_ServiceKind,
+    Text_ServiceKind_String,
     Text_Disabled,
     Text_Disabled_String,
     Text_Default,
@@ -1436,6 +1457,8 @@ enum other
     Other_Language_String3,
     Other_Language_String4,
     Other_Language_More,
+    Other_ServiceKind,
+    Other_ServiceKind_String,
     Other_Disabled,
     Other_Disabled_String,
     Other_Default,
@@ -1547,6 +1570,8 @@ enum image
     Image_Language_String3,
     Image_Language_String4,
     Image_Language_More,
+    Image_ServiceKind,
+    Image_ServiceKind_String,
     Image_Disabled,
     Image_Disabled_String,
     Image_Default,
@@ -1640,11 +1665,13 @@ enum menu
     Menu_Language_String3,
     Menu_Language_String4,
     Menu_Language_More,
+    Menu_ServiceKind,
+    Menu_ServiceKind_String,
     Menu_ServiceName,
     Menu_ServiceChannel,
     Menu_Service_Url,
     Menu_ServiceProvider,
-    Menu_ServiceProviderr_Url,
+    Menu_ServiceProvider_Url,
     Menu_ServiceType,
     Menu_NetworkName,
     Menu_Original_NetworkName,
