@@ -24,13 +24,21 @@
 
 //---------------------------------------------------------------------------
 #include "ZenLib/Utils.h"
+#if defined(MEDIAINFO_FILE_YES)
 #include "ZenLib/File.h"
+#endif //defined(MEDIAINFO_FILE_YES)
 #include "ZenLib/FileName.h"
 #include "MediaInfo/File__Analyze.h"
 #include "MediaInfo/MediaInfo_Config_MediaInfo.h"
 #if MEDIAINFO_IBI
     #include "MediaInfo/Multiple/File_Ibi.h"
 #endif //MEDIAINFO_IBI
+#if MEDIAINFO_FIXITY
+    #ifndef WINDOWS
+    //ZenLib has File::Copy only for Windows for the moment. //TODO: support correctly (including meta)
+    #include <fstream>
+    #endif //WINDOWS
+#endif //MEDIAINFO_FIXITY
 using namespace ZenLib;
 //---------------------------------------------------------------------------
 
@@ -41,6 +49,35 @@ namespace MediaInfoLib
 extern MediaInfo_Config Config;
 //---------------------------------------------------------------------------
 
+//---------------------------------------------------------------------------
+Ztring File__Analyze_Encoded_Library_String (const Ztring &CompanyName, const Ztring &Name, const Ztring &Version, const Ztring &Date, const Ztring &Encoded_Library)
+{
+    if (!Name.empty())
+    {
+        Ztring String;
+        if (!CompanyName.empty())
+        {
+            String+=CompanyName;
+            String+=__T(" ");
+        }
+        String+=Name;
+        if (!Version.empty())
+        {
+            String+=__T(" ");
+            String+=Version;
+        }
+        if (!Date.empty())
+        {
+            String+=__T(" (");
+            String+=Date;
+            String+=__T(")");
+        }
+        return String;
+    }
+    else
+        return Encoded_Library;
+}
+
 //---------------------------------------------------------------------------
 void File__Analyze::Streams_Finish_Global()
 {
@@ -58,7 +95,7 @@ void File__Analyze::Streams_Finish_Global()
     {
         if (Frame_Count_NotParsedIncluded!=(int64u)-1 && File_Offset+Buffer_Size==File_Size)
             Fill(Stream_Video, 0, Video_FrameCount, Frame_Count_NotParsedIncluded);
-        else if (Config->File_Names.size()>1)
+        else if (Config->File_Names.size()>1 && IsRawStream)
             Fill(Stream_Video, 0, Video_FrameCount, Config->File_Names.size());
         #if MEDIAINFO_IBIUSAGE
         else
@@ -100,6 +137,7 @@ void File__Analyze::Streams_Finish_Global()
 }
 
 //---------------------------------------------------------------------------
+#if defined(MEDIAINFO_FILE_YES)
 void File__Analyze::TestContinuousFileNames(size_t CountOfFiles, Ztring FileExtension, bool SkipComputeDelay)
 {
     if (IsSub || !Config->File_TestContinuousFileNames_Get())
@@ -113,6 +151,9 @@ void File__Analyze::TestContinuousFileNames(size_t CountOfFiles, Ztring FileExte
     size_t Pos_Base = (size_t)-1;
     bool AlreadyPresent=Config->File_Names.size()==1?true:false;
     FileName FileToTest(Config->File_Names.Read(Config->File_Names.size()-1));
+    #ifdef WIN32
+        FileToTest.FindAndReplace(__T("/"), __T("\\"), 0, Ztring_Recursive); // "/" is sometimes used on Windows and it is considered as valid
+    #endif //WIN32
     Ztring FileToTest_Name=FileToTest.Name_Get();
     Ztring FileToTest_Name_After=FileToTest_Name;
     size_t FileNameToTest_End=FileToTest_Name.size();
@@ -225,12 +266,13 @@ void File__Analyze::TestContinuousFileNames(size_t CountOfFiles, Ztring FileExte
         return;
 
     Config->File_IsImageSequence=true;
-    Frame_Count_NotParsedIncluded=Pos_Base;
+    if (IsRawStream)
+        Frame_Count_NotParsedIncluded=Pos_Base;
     #if MEDIAINFO_DEMUX
         float64 Demux_Rate=Config->Demux_Rate_Get();
         if (!Demux_Rate)
             Demux_Rate=24;
-        if (!SkipComputeDelay)
+        if (!SkipComputeDelay && Frame_Count_NotParsedIncluded!=(int64u)-1)
             Fill(Stream_Video, 0, Video_Delay, float64_int64s(Frame_Count_NotParsedIncluded*1000/Demux_Rate));
     #endif //MEDIAINFO_DEMUX
 
@@ -281,10 +323,49 @@ void File__Analyze::TestContinuousFileNames(size_t CountOfFiles, Ztring FileExte
                 Temp.erase(0, SourcePath_Size);
                 Fill(Stream_General, 0, "Source_List", Temp);
             }
-            (*Stream_More)[Stream_General][0](Ztring().From_Local("Source_List"), Info_Options)=__T("N NT");
+            Fill_SetOptions(Stream_General, 0, "Source_List", "N NT");
         }
     #endif //MEDIAINFO_ADVANCED
 }
+#endif //defined(MEDIAINFO_FILE_YES)
+
+//---------------------------------------------------------------------------
+#if MEDIAINFO_FIXITY
+bool File__Analyze::FixFile(int64u FileOffsetForWriting, const int8u* ToWrite, const size_t ToWrite_Size)
+{
+    if (Config->File_Names.empty())
+        return false; //Streams without file names are not supported
+        
+    #ifdef WINDOWS
+    File::Copy(Config->File_Names[0], Config->File_Names[0]+__T(".Fixed"));
+    #else //WINDOWS
+    //ZenLib has File::Copy only for Windows for the moment. //TODO: support correctly (including meta)
+    if (!File::Exists(Config->File_Names[0]+__T(".Fixed")))
+    {
+        std::ofstream  Dest(Ztring(Config->File_Names[0]+__T(".Fixed")).To_Local().c_str(), std::ios::binary);
+        if (Dest.fail())
+            return false;
+        std::ifstream  Source(Config->File_Names[0].To_Local().c_str(), std::ios::binary);
+        if (Source.fail())
+            return false;
+        Dest << Source.rdbuf();
+        if (Dest.fail())
+            return false;
+    }
+    #endif //WINDOWS
+
+    File F;
+    if (!F.Open(Config->File_Names[0]+__T(".Fixed"), File::Access_Write))
+        return false;
+
+    if (!F.GoTo(FileOffsetForWriting))
+        return false;
+
+    F.Write(ToWrite, ToWrite_Size);
+
+    return true;
+}
+#endif //MEDIAINFO_FIXITY
 
 //---------------------------------------------------------------------------
 void File__Analyze::Streams_Finish_StreamOnly()
@@ -344,7 +425,7 @@ void File__Analyze::Streams_Finish_StreamOnly(stream_t StreamKind, size_t Pos)
     }
 
     //Duration from Bitrate and StreamSize
-    if (StreamKind!=Stream_Other && Retrieve(StreamKind, Pos, Fill_Parameter(StreamKind, Generic_Duration)).empty() && !Retrieve(StreamKind, Pos, Fill_Parameter(StreamKind, Generic_StreamSize)).empty() && !Retrieve(StreamKind, Pos, "BitRate").empty() && Count_Get(Stream_Video)+Count_Get(Stream_Audio)>1) //If only one stream, duration will be copied later, useful for exact bitrate calculation
+    if (StreamKind!=Stream_Other && Retrieve(StreamKind, Pos, Fill_Parameter(StreamKind, Generic_Duration)).empty() && !Retrieve(StreamKind, Pos, Fill_Parameter(StreamKind, Generic_StreamSize)).empty() && !Retrieve(StreamKind, Pos, "BitRate").empty() && Count_Get(Stream_Video)+Count_Get(Stream_Audio)>1) //If only one stream, duration will be copied later, useful for exact bitrate calculation //TODO: enable it aslo for 1 stream, after handling of incoherencies found during tests
     {
         int64u BitRate=Retrieve(StreamKind, Pos, "BitRate").To_int64u();
         int64u StreamSize=Retrieve(StreamKind, Pos, Fill_Parameter(StreamKind, Generic_StreamSize)).To_int64u();
@@ -371,8 +452,27 @@ void File__Analyze::Streams_Finish_StreamOnly(stream_t StreamKind, size_t Pos)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Streams_Finish_StreamOnly_General(size_t UNUSED(StreamPos))
+void File__Analyze::Streams_Finish_StreamOnly_General(size_t StreamPos)
 {
+    //File extension test
+    if (Retrieve(Stream_General, StreamPos, "FileExtension_Invalid").empty())
+    {
+        const Ztring& Name=Retrieve(Stream_General, StreamPos, General_FileName);
+        const Ztring& Extension=Retrieve(Stream_General, StreamPos, General_FileExtension);
+        if (!Name.empty() || !Extension.empty())
+        {
+            InfoMap &FormatList=MediaInfoLib::Config.Format_Get();
+            InfoMap::iterator Format=FormatList.find(Retrieve(Stream_General, StreamPos, General_Format));
+            if (Format!=FormatList.end())
+            {
+                ZtringList ValidExtensions;
+                ValidExtensions.Separator_Set(0, __T(" "));
+                ValidExtensions.Write(FormatList.Get(Format->first, InfoFormat_Extensions));
+                if (!ValidExtensions.empty() && ValidExtensions.Find(Extension)==string::npos)
+                    Fill(Stream_General, StreamPos, "FileExtension_Invalid", ValidExtensions.Read());
+            }
+        }
+    }
 }
 
 //---------------------------------------------------------------------------
@@ -458,7 +558,7 @@ void File__Analyze::Streams_Finish_StreamOnly_Video(size_t Pos)
 
     //Commercial name
     #if defined(MEDIAINFO_VC3_YES)
-        if (Retrieve(Stream_Video, Pos, Video_Format_Commercial_IfAny).empty() && Retrieve(Stream_Video, Pos, Video_Format)==__T("VC-3"))
+        if (Retrieve(Stream_Video, Pos, Video_Format_Commercial_IfAny).empty() && Retrieve(Stream_Video, Pos, Video_Format)==__T("VC-3") && Retrieve(Stream_Video, Pos, Video_Format_Profile).find(__T("HD"))==0)
         {
             //http://www.avid.com/static/resources/US/documents/dnxhd.pdf
             int64u Height=Retrieve(Stream_Video, Pos, Video_Height).To_int64u();
@@ -581,12 +681,27 @@ void File__Analyze::Streams_Finish_StreamOnly_Video(size_t Pos)
                     Fill(Stream_Video, Pos, Video_Format_Commercial_IfAny, __T("DNxHD ")+Ztring::ToZtring(BitRate_Final)+(BitDepth==10?__T("x"):__T(""))); //"x"=10-bit
             }
         }
+        if (Retrieve(Stream_Video, Pos, Video_Format_Commercial_IfAny).empty() && Retrieve(Stream_Video, Pos, Video_Format)==__T("VC-3") && Retrieve(Stream_Video, Pos, Video_Format_Profile).find(__T("RI@"))==0)
+        {
+            Fill(Stream_Video, Pos, Video_Format_Commercial_IfAny, __T("DNxHR ")+Retrieve(Stream_Video, Pos, Video_Format_Profile).substr(3));
+        }
     #endif //defined(MEDIAINFO_VC3_YES)
 }
 
 //---------------------------------------------------------------------------
 void File__Analyze::Streams_Finish_StreamOnly_Audio(size_t Pos)
 {
+    //Channels
+    if (Retrieve(Stream_Audio, Pos, Audio_Channel_s_).empty())
+    {
+        const Ztring& CodecID=Retrieve(Stream_Audio, Pos, Audio_CodecID);
+        if (CodecID==__T("samr")
+         || CodecID==__T("sawb")
+         || CodecID==__T("7A21")
+         || CodecID==__T("7A22"))
+        Fill(Stream_Audio, Pos, Audio_Channel_s_, 1); //AMR is always with 1 channel
+    }
+
     //SamplingCount
     if (Retrieve(Stream_Audio, Pos, Audio_SamplingCount).empty())
     {
@@ -1013,8 +1128,8 @@ void File__Analyze::Streams_Finish_HumanReadable()
 //---------------------------------------------------------------------------
 void File__Analyze::Streams_Finish_HumanReadable_PerStream(stream_t StreamKind, size_t StreamPos, size_t Parameter)
 {
-    Ztring ParameterName=Retrieve(StreamKind, StreamPos, Parameter, Info_Name);
-    Ztring Value=Retrieve(StreamKind, StreamPos, Parameter, Info_Text);
+    const Ztring ParameterName=Retrieve(StreamKind, StreamPos, Parameter, Info_Name);
+    const Ztring Value=Retrieve(StreamKind, StreamPos, Parameter, Info_Text);
 
     //Strings
     const Ztring &List_Measure_Value=MediaInfoLib::Config.Info_Get(StreamKind).Read(Parameter, Info_Measure);
@@ -1066,7 +1181,7 @@ void File__Analyze::Streams_Finish_HumanReadable_PerStream(stream_t StreamKind,
         for (size_t Pos=0; Pos<List.size(); Pos++)
             List[Pos]=MediaInfoLib::Config.Language_Get(Ztring(__T("BitRate_Mode_"))+List[Pos]);
 
-        Ztring Translated=List.Read();
+        const Ztring Translated=List.Read();
         Fill(StreamKind, StreamPos, StreamKind==Stream_General?"OverallBitRate_Mode/String":"BitRate_Mode/String", Translated.find(__T("BitRate_Mode_"))?Translated:Value);
     }
 
@@ -1120,49 +1235,24 @@ void File__Analyze::Streams_Finish_HumanReadable_PerStream(stream_t StreamKind,
         Ztring Name=Retrieve(StreamKind, StreamPos, "Encoded_Library_Name");
         Ztring Version=Retrieve(StreamKind, StreamPos, "Encoded_Library_Version");
         Ztring Date=Retrieve(StreamKind, StreamPos, "Encoded_Library_Date");
-        if (!Name.empty())
-        {
-            Ztring String;
-            if (!CompanyName.empty())
-            {
-                String+=CompanyName;
-                String+=__T(" ");
-            }
-            String+=Name;
-            if (!Version.empty())
-            {
-                String+=__T(" ");
-                String+=Version;
-            }
-            if (!Date.empty())
-            {
-                String+=__T(" (");
-                String+=Date;
-                String+=__T(")");
-            }
-            Fill(StreamKind, StreamPos, "Encoded_Library/String", String, true);
-        }
-        else
-            Fill(StreamKind, StreamPos, "Encoded_Library/String", Retrieve(StreamKind, StreamPos, "Encoded_Library"), true);
+        Ztring Encoded_Library=Retrieve(StreamKind, StreamPos, "Encoded_Library");
+        Fill(StreamKind, StreamPos, "Encoded_Library/String", File__Analyze_Encoded_Library_String(CompanyName, Name, Version, Date, Encoded_Library), true);
     }
 
     //Format_Settings_Matrix
     if (StreamKind==Stream_Video && Parameter==Video_Format_Settings_Matrix)
     {
-        Ztring Translated=MediaInfoLib::Config.Language_Get(Ztring(__T("Format_Settings_Matrix_"))+Value);
-        Fill(Stream_Video, StreamPos, Video_Format_Settings_Matrix_String, Translated.find(__T("Format_Settings_Matrix_"))?Translated:Value);
+        Fill(Stream_Video, StreamPos, Video_Format_Settings_Matrix_String, MediaInfoLib::Config.Language_Get_Translate(__T("Format_Settings_Matrix_"), Value));
     }
 
     //Scan type
     if (StreamKind==Stream_Video && Parameter==Video_ScanType)
     {
-        Ztring Translated=MediaInfoLib::Config.Language_Get(Ztring(__T("Interlaced_"))+Value);
-        Fill(Stream_Video, StreamPos, Video_ScanType_String, Translated.find(__T("Interlaced_"))?Translated:Value);
+        Fill(Stream_Video, StreamPos, Video_ScanType_String, MediaInfoLib::Config.Language_Get_Translate(__T("Interlaced_"), Value));
     }
     if (StreamKind==Stream_Video && Parameter==Video_ScanType_Original)
     {
-        Ztring Translated=MediaInfoLib::Config.Language_Get(Ztring(__T("Interlaced_"))+Value);
-        Fill(Stream_Video, StreamPos, Video_ScanType_Original_String, Translated.find(__T("Interlaced_"))?Translated:Value);
+        Fill(Stream_Video, StreamPos, Video_ScanType_Original_String, MediaInfoLib::Config.Language_Get_Translate(__T("Interlaced_"), Value));
     }
     if (StreamKind==Stream_Video && Parameter==Video_ScanType_StoreMethod)
     {
@@ -1176,18 +1266,15 @@ void File__Analyze::Streams_Finish_HumanReadable_PerStream(stream_t StreamKind,
     //Scan order
     if (StreamKind==Stream_Video && Parameter==Video_ScanOrder)
     {
-        Ztring Translated=MediaInfoLib::Config.Language_Get(Ztring(__T("Interlaced_"))+Value);
-        Fill(Stream_Video, StreamPos, Video_ScanOrder_String, Translated.find(__T("Interlaced_"))?Translated:Value);
+        Fill(Stream_Video, StreamPos, Video_ScanOrder_String, MediaInfoLib::Config.Language_Get_Translate(__T("Interlaced_"), Value));
     }
     if (StreamKind==Stream_Video && Parameter==Video_ScanOrder_Stored)
     {
-        Ztring Translated=MediaInfoLib::Config.Language_Get(Ztring(__T("Interlaced_"))+Value);
-        Fill(Stream_Video, StreamPos, Video_ScanOrder_Stored_String, Translated.find(__T("Interlaced_"))?Translated:Value);
+        Fill(Stream_Video, StreamPos, Video_ScanOrder_Stored_String, MediaInfoLib::Config.Language_Get_Translate(__T("Interlaced_"), Value));
     }
     if (StreamKind==Stream_Video && Parameter==Video_ScanOrder_Original)
     {
-        Ztring Translated=MediaInfoLib::Config.Language_Get(Ztring(__T("Interlaced_"))+Value);
-        Fill(Stream_Video, StreamPos, Video_ScanOrder_Original_String, Translated.find(__T("Interlaced_"))?Translated:Value);
+        Fill(Stream_Video, StreamPos, Video_ScanOrder_Original_String, MediaInfoLib::Config.Language_Get_Translate(__T("Interlaced_"), Value));
     }
 
     //Interlacement
@@ -1205,29 +1292,25 @@ void File__Analyze::Streams_Finish_HumanReadable_PerStream(stream_t StreamKind,
     //FrameRate_Mode
     if (StreamKind==Stream_Video && Parameter==Video_FrameRate_Mode)
     {
-        Ztring Translated=MediaInfoLib::Config.Language_Get(Ztring(__T("FrameRate_Mode_"))+Value);
-        Fill(Stream_Video, StreamPos, Video_FrameRate_Mode_String, Translated.find(__T("FrameRate_Mode_"))?Translated:Value);
+        Fill(Stream_Video, StreamPos, Video_FrameRate_Mode_String, MediaInfoLib::Config.Language_Get_Translate(__T("FrameRate_Mode_"), Value));
     }
 
     //Compression_Mode
     if (Parameter==Fill_Parameter(StreamKind, Generic_Compression_Mode))
     {
-        Ztring Translated=MediaInfoLib::Config.Language_Get(Ztring(__T("Compression_Mode_"))+Value);
-        Fill(StreamKind, StreamPos, Fill_Parameter(StreamKind, Generic_Compression_Mode_String), Translated.find(__T("Compression_Mode_"))?Translated:Value);
+        Fill(StreamKind, StreamPos, Fill_Parameter(StreamKind, Generic_Compression_Mode_String), MediaInfoLib::Config.Language_Get_Translate(__T("Compression_Mode_"), Value));
     }
 
     //Delay_Source
     if (Parameter==Fill_Parameter(StreamKind, Generic_Delay_Source))
     {
-        Ztring Translated=MediaInfoLib::Config.Language_Get(Ztring(__T("Delay_Source_"))+Value);
-        Fill(StreamKind, StreamPos, Fill_Parameter(StreamKind, Generic_Delay_Source_String), Translated.find(__T("Delay_Source_"))?Translated:Value);
+        Fill(StreamKind, StreamPos, Fill_Parameter(StreamKind, Generic_Delay_Source_String), MediaInfoLib::Config.Language_Get_Translate(__T("Delay_Source_"), Value));
     }
 
     //Gop_OpenClosed
     if (StreamKind==Stream_Video && (Parameter==Video_Gop_OpenClosed || Parameter==Video_Gop_OpenClosed_FirstFrame))
     {
-        Ztring Translated=MediaInfoLib::Config.Language_Get(Ztring(__T("Gop_OpenClosed_"))+Value);
-        Fill(Stream_Video, StreamPos, Parameter+1, Translated.find(__T("Gop_OpenClosed_"))?Translated:Value, true);
+        Fill(Stream_Video, StreamPos, Parameter+1, MediaInfoLib::Config.Language_Get_Translate(__T("Gop_OpenClosed_"), Value), true);
     }
 }
 
