@@ -83,6 +83,9 @@
 #if defined(MEDIAINFO_MK_YES)
     #include "MediaInfo/Multiple/File_Mk.h"
 #endif
+#if defined(MEDIAINFO_MIXML_YES)
+    #include "MediaInfo/Multiple/File_MiXml.h"
+#endif
 #if defined(MEDIAINFO_MPEG4_YES)
     #include "MediaInfo/Multiple/File_Mpeg4.h"
 #endif
@@ -128,7 +131,7 @@
 #if defined(MEDIAINFO_WM_YES)
     #include "MediaInfo/Multiple/File_Wm.h"
 #endif
-#if defined(MEDIAINFO_WM_YES)
+#if defined(MEDIAINFO_WTV_YES)
     #include "MediaInfo/Multiple/File_Wtv.h"
 #endif
 #if defined(MEDIAINFO_XDCAM_YES)
@@ -460,6 +463,9 @@ File__MultipleParsing::File__MultipleParsing()
     #if defined(MEDIAINFO_MK_YES)
         Parser.push_back(new File_Mk());
     #endif
+    #if defined(MEDIAINFO_MIXML_YES)
+        Parser.push_back(new File_MiXml());
+    #endif
     #if defined(MEDIAINFO_MPEG4_YES)
         Parser.push_back(new File_Mpeg4());
     #endif
