@@ -304,30 +304,38 @@ enum Elements
 //***************************************************************************
 
 //
-string DPX_DateTime2Iso(const string &FromDpx)
+bool DPX_DateTime_Valid(const string &FromDpx)
 {
-    if (FromDpx.size()<20
+    if (FromDpx.size()<19
      || FromDpx[ 0]<'0' || FromDpx[ 0]>'9'
      || FromDpx[ 1]<'0' || FromDpx[ 1]>'9'
      || FromDpx[ 2]<'0' || FromDpx[ 2]>'9'
      || FromDpx[ 3]<'0' || FromDpx[ 3]>'9'
      || FromDpx[ 4] != ':'
-     || FromDpx[ 5]<'0' || FromDpx[ 5]>'9'
+     || FromDpx[ 5]<'0' || FromDpx[ 5]>'1'
      || FromDpx[ 6]<'0' || FromDpx[ 6]>'9'
      || FromDpx[ 7] != ':'
-     || FromDpx[ 8]<'0' || FromDpx[ 8]>'9'
+     || FromDpx[ 8]<'0' || FromDpx[ 8]>'3'
      || FromDpx[ 9]<'0' || FromDpx[ 9]>'9'
      || FromDpx[10] != ':'
-     || FromDpx[11]<'0' || FromDpx[11]>'9'
+     || FromDpx[11]<'0' || FromDpx[11]>'2'
      || FromDpx[12]<'0' || FromDpx[12]>'9'
      || FromDpx[13] != ':'
-     || FromDpx[14]<'0' || FromDpx[14]>'9'
+     || FromDpx[14]<'0' || FromDpx[14]>'5'
      || FromDpx[15]<'0' || FromDpx[15]>'9'
      || FromDpx[16] != ':'
-     || FromDpx[17]<'0' || FromDpx[17]>'9'
+     || FromDpx[17]<'0' || FromDpx[17]>'5'
      || FromDpx[18]<'0' || FromDpx[18]>'9'
      )
-        return FromDpx; //Invalid, returning the value in the file
+        return false;
+
+    return true;
+}
+
+string DPX_DateTime2Iso(const string &FromDpx)
+{
+    if (!DPX_DateTime_Valid(FromDpx))
+        return string();
 
     // Date/Time
     string ToReturn(FromDpx.substr(0, 19));
@@ -369,6 +377,7 @@ File_Dpx::File_Dpx()
 {
     //Configuration
     ParserName="DPX";
+    IsRawStream=true;
 }
 
 //***************************************************************************
@@ -542,10 +551,10 @@ void File_Dpx::GenericSectionHeader_Cineon()
     Get_X4 (Size_Industry,                                      "Industry specific header length");
     Get_X4 (Size_User,                                          "User-defined header length");
     Get_X4 (Size_Total,                                         "Total image file size");
-    Get_String(8, Version,                                      "Version number of header format");
+    Get_ASCII  (8, Version,                                     "Version number of header format");
     Skip_UTF8  (100,                                            "FileName");
-    Get_String (12,  CreationDate,                              "Creation Date");
-    Get_String (12,  CreationTime,                              "Creation Time");
+    Get_ASCII  (12,  CreationDate,                              "Creation Date");
+    Get_ASCII  (12,  CreationTime,                              "Creation Time");
     Skip_XX(36,                                                 "Reserved for future use");
     Element_End0();
 
@@ -585,8 +594,8 @@ void File_Dpx::GenericSectionHeader_Cineon()
     Skip_B4(                                                    "X offset");
     Skip_B4(                                                    "Y offset");
     Skip_UTF8  (100,                                            "FileName");
-    Get_String (12,  CreationDate,                              "Creation Date");
-    Get_String (12,  CreationTime,                              "Creation Time");
+    Get_ASCII  (12,  CreationDate,                              "Creation Date");
+    Get_ASCII  (12,  CreationTime,                              "Creation Time");
     Skip_UTF8(64,                                               "Input device");
     Skip_UTF8(32,                                               "Input device model number");
     Skip_UTF8(32,                                               "Input device serial number");
@@ -664,17 +673,17 @@ void File_Dpx::GenericSectionHeader_Dpx()
     int32u Size_Header, Size_Total, Size_Generic, Size_Industry, Size_User;
     Skip_String(4,                                              "Magic number");
     Get_X4 (Size_Header,                                        "Offset to image data");
-    Get_String(8, Version,                                      "Version number of header format");
+    Get_ASCII (8, Version,                                      "Version number of header format");
     Get_X4 (Size_Total,                                         "Total image file size");
     Skip_B4(                                                    "Ditto Key");
     Get_X4 (Size_Generic,                                       "Generic section header length");
     Get_X4 (Size_Industry,                                      "Industry specific header length");
     Get_X4 (Size_User,                                          "User-defined header length");
     Skip_UTF8  (100,                                            "FileName");
-    Get_String (24,  CreationDate,                              "Creation Date");
-    Get_String (100, Creator,                                   "Creator");
-    Get_String (200, Project,                                   "Project");
-    Get_String (200, Copyright,                                 "Right to use or copyright statement");
+    Get_ASCII  (24,  CreationDate,                              "Creation Date");
+    Get_ASCII  (100, Creator,                                   "Creator");
+    Get_ASCII  (200, Project,                                   "Project");
+    Get_ASCII  (200, Copyright,                                 "Right to use or copyright statement");
     Skip_B4(                                                    "Encryption key");
     Skip_XX(104,                                                "Reserved for future use");
     Element_End0();
@@ -682,7 +691,7 @@ void File_Dpx::GenericSectionHeader_Dpx()
     Element_Begin1("Image information");
     int32u Width, Height, PAR_H, PAR_V;
     int16u ImageElements;
-    Info_B2(ImageOrientation,                                   "Image orientation");Param_Info1(DPX_Orientation[ImageOrientation]);
+    Info_X2(ImageOrientation,                                   "Image orientation");Param_Info1(DPX_Orientation[ImageOrientation]);
     Get_X2 (ImageElements,                                      "Number of image elements");
     if (ImageElements>8)
         ImageElements=8;
@@ -774,7 +783,7 @@ void File_Dpx::GenericSectionHeader_Dpx_ImageElement()
 {
     Element_Begin1("image element");
     int8u Descriptor, TransferCharacteristic, ColorimetricSpecification, BitDephs;
-    Info_B4(DataSign,                                           "Data sign");Param_Info1((DataSign==0?"unsigned":"signed"));
+    Info_X4(DataSign,                                           "Data sign");Param_Info1((DataSign==0?"unsigned":"signed"));
     Skip_B4(                                                    "Reference low data code value");
     Skip_BF4(                                                   "Reference low quantity represented");
     Skip_B4(                                                    "Reference high data code value");
@@ -783,8 +792,8 @@ void File_Dpx::GenericSectionHeader_Dpx_ImageElement()
     Get_B1 (TransferCharacteristic,                             "Transfer characteristic");Param_Info1(DPX_TransferCharacteristic(TransferCharacteristic));
     Get_B1 (ColorimetricSpecification,                          "Colorimetric specification");Param_Info1(DPX_ColorimetricSpecification(ColorimetricSpecification));
     Get_B1 (BitDephs,                                           "Bit depth");Param_Info1(DPX_ValidBitDephs(BitDephs));
-    Info_B2(ComponentDataPackingMethod,                         "Packing");Param_Info1((ComponentDataPackingMethod<8?DPX_ComponentDataPackingMethod[ComponentDataPackingMethod]:"invalid"));
-    Info_B2(ComponentDataEncodingMethod,                        "Encoding");Param_Info1((ComponentDataEncodingMethod<8?DPX_ComponentDataEncodingMethod[ComponentDataEncodingMethod]:"invalid"));
+    Info_X2(ComponentDataPackingMethod,                         "Packing");Param_Info1((ComponentDataPackingMethod<8?DPX_ComponentDataPackingMethod[ComponentDataPackingMethod]:"invalid"));
+    Info_X2(ComponentDataEncodingMethod,                        "Encoding");Param_Info1((ComponentDataEncodingMethod<8?DPX_ComponentDataEncodingMethod[ComponentDataEncodingMethod]:"invalid"));
     Skip_B4(                                                    "Offset to data");
     Skip_B4(                                                    "End-of-line padding");
     Skip_B4(                                                    "End-of-image padding");
@@ -843,7 +852,7 @@ void File_Dpx::IndustrySpecificHeader_Dpx()
     Skip_B4(                                                    "Frame position in sequence");
     Skip_B4(                                                    "Sequence length (frames)");
     Skip_B4(                                                    "Held count (1 = default)");
-    Get_BF4 (FrameRate,                                         "Frame rate of original (frames/s)");
+    Get_XF4 (FrameRate,                                         "Frame rate of original (frames/s)");
     Skip_BF4(                                                   "Shutter angle of camera in degrees");
     Skip_UTF8(32,                                               "Frame identification - e.g. keyframe");
     Skip_UTF8(100,                                              "Slate information");
@@ -948,6 +957,30 @@ void File_Dpx::Get_X4(int32u &Info, const char* Name)
         Get_B4 (Info,                                           Name);
 }
 
+//---------------------------------------------------------------------------
+void File_Dpx::Get_XF4(float32 &Info, const char* Name)
+{
+    if (LittleEndian)
+        Get_LF4 (Info,                                           Name);
+    else
+        Get_BF4 (Info,                                           Name);
+}
+
+//---------------------------------------------------------------------------
+void File_Dpx::Get_ASCII(size_t Size, string &Info, const char* Name)
+{
+    //Looking for end of string (null byte)
+    size_t NullPos=0;
+    while (NullPos<Size && Element_Offset+NullPos<Element_Size)
+    {
+        if (!Buffer[Buffer_Offset+(size_t)Element_Offset+ NullPos])
+            break;
+        NullPos++;
+    }
+    Get_String (NullPos, Info,                                  Name);
+    Element_Offset+=Size-NullPos; //Skipping bytes including null bytes and bytes after null byte
+}
+
 } //NameSpace
 
 #endif //MEDIAINFO_DPX_YES
