@@ -1,21 +1,5 @@
 // MediaInfo - All info about media files
-// Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+
 
 //---------------------------------------------------------------------------
 // Pre-compilation
@@ -32,6 +16,9 @@
 //---------------------------------------------------------------------------
 #include "MediaInfo/MediaInfo.h"
 #include "MediaInfo/MediaInfo_Internal.h"
+#if defined(_MSC_VER) && _MSC_VER >= 1800 && _MSC_VER < 1900 && defined(_M_X64)
+    #include <math.h> // needed for _set_FMA3_enable()
+#endif
 using namespace ZenLib;
 //---------------------------------------------------------------------------
 
@@ -76,12 +63,19 @@ using namespace MediaInfo_Debug_MediaInfo;
 MediaInfo::MediaInfo()
 {
     Internal=new MediaInfo_Internal();
+
+    // FMA3 support in the 2013 CRT is broken on Vista and Windows 7 RTM (fixed in SP1).
+    // See https://connect.microsoft.com/VisualStudio/feedback/details/987093/x64-log-function-uses-vpsrlq-avx-instruction-without-regard-to-operating-system-so-it-crashes-on-vista-x64
+    // Hotfix: we disable it for MSVC2013.
+    #if defined(_MSC_VER) && _MSC_VER >= 1800 && _MSC_VER < 1900 && defined(_M_X64)
+        _set_FMA3_enable(0);
+    #endif
 }
 
 //---------------------------------------------------------------------------
 MediaInfo::~MediaInfo()
 {
-    delete (MediaInfo_Internal*)Internal; //Internal=NULL;
+    delete Internal; //Internal=NULL;
 }
 
 //***************************************************************************
@@ -91,43 +85,47 @@ MediaInfo::~MediaInfo()
 //---------------------------------------------------------------------------
 size_t MediaInfo::Open(const String &File_Name_)
 {
-    return ((MediaInfo_Internal*)Internal)->Open(File_Name_);
+#if defined(MEDIAINFO_FILE_YES)
+    return Internal->Open(File_Name_);
+#else //defined(MEDIAINFO_FILE_YES)
+    return 0; //Not available
+#endif //defined(MEDIAINFO_FILE_YES)
 }
 
 //---------------------------------------------------------------------------
 size_t MediaInfo::Open (const int8u* Begin, size_t Begin_Size, const int8u* End, size_t End_Size, int64u File_Size)
 {
-    return ((MediaInfo_Internal*)Internal)->Open(Begin, Begin_Size, End, End_Size, (File_Size<Begin_Size+End_Size)?(Begin_Size+End_Size):File_Size);
+    return Internal->Open(Begin, Begin_Size, End, End_Size, (File_Size<Begin_Size+End_Size)?(Begin_Size+End_Size):File_Size);
 }
 
 //---------------------------------------------------------------------------
 size_t MediaInfo::Open_Buffer_Init (int64u File_Size, int64u File_Offset)
 {
-    return ((MediaInfo_Internal*)Internal)->Open_Buffer_Init(File_Size, File_Offset);
+    return Internal->Open_Buffer_Init(File_Size, File_Offset);
 }
 
 //---------------------------------------------------------------------------
 size_t MediaInfo::Open_Buffer_Continue (const int8u* ToAdd, size_t ToAdd_Size)
 {
-    return ((MediaInfo_Internal*)Internal)->Open_Buffer_Continue(ToAdd, ToAdd_Size).to_ulong();
+    return Internal->Open_Buffer_Continue(ToAdd, ToAdd_Size).to_ulong();
 }
 
 //---------------------------------------------------------------------------
 int64u MediaInfo::Open_Buffer_Continue_GoTo_Get ()
 {
-    return ((MediaInfo_Internal*)Internal)->Open_Buffer_Continue_GoTo_Get();
+    return Internal->Open_Buffer_Continue_GoTo_Get();
 }
 
 //---------------------------------------------------------------------------
 size_t MediaInfo::Open_Buffer_Finalize ()
 {
-    return ((MediaInfo_Internal*)Internal)->Open_Buffer_Finalize();
+    return Internal->Open_Buffer_Finalize();
 }
 
 //---------------------------------------------------------------------------
 size_t MediaInfo::Open_NextPacket ()
 {
-    return ((MediaInfo_Internal*)Internal)->Open_NextPacket().to_ulong();;
+    return Internal->Open_NextPacket().to_ulong();
 }
 
 //---------------------------------------------------------------------------
@@ -139,7 +137,7 @@ size_t MediaInfo::Save()
 //---------------------------------------------------------------------------
 void MediaInfo::Close()
 {
-    return ((MediaInfo_Internal*)Internal)->Close();
+    return Internal->Close();
 }
 
 //***************************************************************************
@@ -149,19 +147,19 @@ void MediaInfo::Close()
 //---------------------------------------------------------------------------
 String MediaInfo::Inform(size_t)
 {
-    return ((MediaInfo_Internal*)Internal)->Inform();
+    return Internal->Inform();
 }
 
 //---------------------------------------------------------------------------
 String MediaInfo::Get(stream_t StreamKind, size_t StreamPos, size_t Parameter, info_t KindOfInfo)
 {
-    return ((MediaInfo_Internal*)Internal)->Get(StreamKind, StreamPos, Parameter, KindOfInfo);
+    return Internal->Get(StreamKind, StreamPos, Parameter, KindOfInfo);
 }
 
 //---------------------------------------------------------------------------
 String MediaInfo::Get(stream_t StreamKind, size_t StreamPos, const String &Parameter, info_t KindOfInfo, info_t KindOfSearch)
 {
-    return ((MediaInfo_Internal*)Internal)->Get(StreamKind, StreamPos, Parameter, KindOfInfo, KindOfSearch);
+    return Internal->Get(StreamKind, StreamPos, Parameter, KindOfInfo, KindOfSearch);
 }
 
 //***************************************************************************
@@ -187,13 +185,13 @@ size_t MediaInfo::Set(const String &, stream_t, size_t, const String &, const St
 //---------------------------------------------------------------------------
 size_t MediaInfo::Output_Buffer_Get (const String &Value)
 {
-    return ((MediaInfo_Internal*)Internal)->Output_Buffer_Get(Value);
+    return Internal->Output_Buffer_Get(Value);
 }
 
 //---------------------------------------------------------------------------
 size_t MediaInfo::Output_Buffer_Get (size_t Pos)
 {
-    return ((MediaInfo_Internal*)Internal)->Output_Buffer_Get(Pos);
+    return Internal->Output_Buffer_Get(Pos);
 }
 
 //***************************************************************************
@@ -203,7 +201,7 @@ size_t MediaInfo::Output_Buffer_Get (size_t Pos)
 //---------------------------------------------------------------------------
 String MediaInfo::Option (const String &Option, const String &Value)
 {
-    return ((MediaInfo_Internal*)Internal)->Option(Option, Value);
+    return Internal->Option(Option, Value);
 }
 
 //---------------------------------------------------------------------------
@@ -212,7 +210,7 @@ String MediaInfo::Option_Static (const String &Option, const String &Value)
     MEDIAINFO_DEBUG_STATIC(Debug+=__T("Option_Static, Option=");Debug+=Ztring(Option);Debug+=__T(", Value=");Debug+=Ztring(Value);)
     MediaInfoLib::Config.Init(); //Initialize Configuration
 
-         if (Option==__T("Info_Capacities"))
+    if (Option==__T("Info_Capacities"))
     {
         return __T("Option disactivated for this version, will come back soon!");
         //MediaInfo_Internal MI;
@@ -232,16 +230,14 @@ String MediaInfo::Option_Static (const String &Option, const String &Value)
 //---------------------------------------------------------------------------
 size_t MediaInfo::Count_Get (stream_t StreamKind, size_t StreamPos)
 {
-    return ((MediaInfo_Internal*)Internal)->Count_Get(StreamKind, StreamPos);
+    return Internal->Count_Get(StreamKind, StreamPos);
 
 }
 
 //---------------------------------------------------------------------------
 size_t MediaInfo::State_Get ()
 {
-    return ((MediaInfo_Internal*)Internal)->State_Get();
+    return Internal->State_Get();
 }
 
 } //NameSpace
-
-
