@@ -18,8 +18,12 @@
 //---------------------------------------------------------------------------
 #include "MediaInfo/MediaInfoList_Internal.h"
 #include "MediaInfo/MediaInfo_Config.h"
+#if defined(MEDIAINFO_FILE_YES)
 #include "ZenLib/File.h"
+#endif //defined(MEDIAINFO_FILE_YES)
+#if defined(MEDIAINFO_DIRECTORY_YES)
 #include "ZenLib/Dir.h"
+#endif //defined(MEDIAINFO_DIRECTORY_YES)
 #include "MediaInfo/Reader/Reader_Directory.h"
 #include "MediaInfo/File__Analyse_Automatic.h"
 using namespace ZenLib;
@@ -85,17 +89,22 @@ size_t MediaInfoList_Internal::Open(const String &File_Name, const fileoptions_t
     size_t Pos=File_Name.find(__T(':'));
     if (Pos!=string::npos && Pos!=1)
         List.push_back(File_Name);
+    #if defined(MEDIAINFO_FILE_YES)
     else if (File::Exists(File_Name))
         List.push_back(File_Name);
+    #endif //defined(MEDIAINFO_FILE_YES)
+    #if defined(MEDIAINFO_DIRECTORY_YES)
     else
         List=Dir::GetAllFileNames(File_Name, (Options&FileOption_NoRecursive)?Dir::Include_Files:((Dir::dirlist_t)(Dir::Include_Files|Dir::Parse_SubDirs)));
+    #endif //defined(MEDIAINFO_DIRECTORY_YES)
 
     #if defined(MEDIAINFO_DIRECTORY_YES)
         Reader_Directory().Directory_Cleanup(List);
     #endif //defined(MEDIAINFO_DIRECTORY_YES)
 
     //Registering files
-    CS.Enter();
+    {
+    CriticalSectionLocker CSL(CS);
     if (ToParse.empty())
         CountValid=0;
     for (ZtringList::iterator L=List.begin(); L!=List.end(); ++L)
@@ -105,18 +114,17 @@ size_t MediaInfoList_Internal::Open(const String &File_Name, const fileoptions_t
         State=ToParse_AlreadyDone*10000/ToParse_Total;
     else
         State=10000;
-    CS.Leave();
+    }
 
     //Parsing
     if (BlockMethod==1)
     {
-        CS.Enter();
+        CriticalSectionLocker CSL(CS);
         if (!IsRunning()) //If already created, the routine will read the new files
         {
             RunAgain();
             IsInThread=true;
         }
-        CS.Leave();
         return 0;
     }
     else
@@ -390,7 +398,7 @@ String MediaInfoList_Internal::Inform(size_t FilePos, size_t)
             return Result;
         }
 
-        if (MediaInfoLib::Config.Inform_Get()==__T("MIXML"))
+        if (MediaInfoLib::Config.Inform_Get()==__T("XML") || MediaInfoLib::Config.Inform_Get()==__T("MIXML"))
         {
             Ztring Result;
             Result+=__T("<?xml version=\"1.0\" encoding=\"UTF-8\"?>")+MediaInfoLib::Config.LineSeparator_Get();
@@ -403,9 +411,8 @@ String MediaInfoList_Internal::Inform(size_t FilePos, size_t)
             Result+=MediaInfoLib::Config.LineSeparator_Get();
             Result+=__T("    xsi:schemaLocation=\"http")+(MediaInfoLib::Config.Https_Get()?Ztring(__T("s")):Ztring())+__T("://mediaarea.net/mediainfo http")+(MediaInfoLib::Config.Https_Get()?Ztring(__T("s")):Ztring())+__T("://mediaarea.net/mediainfo/mediainfo_2_0.xsd\"");
             Result+=MediaInfoLib::Config.LineSeparator_Get();
-            Result+=__T("    version=\"2.0beta1\"");
+            Result+=__T("    version=\"2.0\"");
             Result+=__T(">")+MediaInfoLib::Config.LineSeparator_Get();
-            Result+=__T("<!-- Work in progress, not for production -->")+MediaInfoLib::Config.LineSeparator_Get();
             Result+=__T("<creatingLibrary version=\"")+Ztring(MediaInfo_Version).SubString(__T(" - v"), Ztring())+__T("\" url=\"http")+(MediaInfoLib::Config.Https_Get()?Ztring(__T("s")):Ztring())+__T("://mediaarea.net/MediaInfo\">MediaInfoLib</creatingLibrary>");
             Result+=MediaInfoLib::Config.LineSeparator_Get();
 
@@ -426,7 +433,7 @@ String MediaInfoList_Internal::Inform(size_t FilePos, size_t)
         ZtringListList MediaInfo_Custom_View; MediaInfo_Custom_View.Write(Option(__T("Inform_Get")));
         #if defined(MEDIAINFO_XML_YES)
         bool XML=false;
-        if (MediaInfoLib::Config.Inform_Get()==__T("XML"))
+        if (MediaInfoLib::Config.Inform_Get()==__T("OLDXML"))
             XML=true;
         if (XML)
         {
@@ -553,8 +560,8 @@ String MediaInfoList_Internal::Option (const String &Option, const String &Value
 {
     CriticalSectionLocker CSL(CS);
     Ztring OptionLower=Option; OptionLower.MakeLowerCase();
-         if (Option==__T(""))
-        return __T("");
+    if (Option.empty())
+        return String();
     else if (OptionLower==__T("manguage_update"))
     {
         //Special case : Language_Update must update all MediaInfo classes
