@@ -39,6 +39,14 @@ using std::make_pair;
 namespace MediaInfoLib
 {
 
+enum basicformat
+{
+    BasicFormat_Text,
+    BasicFormat_CSV,
+    BasicFormat_XML,
+    BasicFormat_JSON,
+};
+
 //***************************************************************************
 // Class MediaInfo_Config
 //***************************************************************************
@@ -101,6 +109,9 @@ public :
           void      Compat_Set (int64u NewValue);
           int64u    Compat_Get ();
 
+          void      Https_Set(bool NewValue);
+          bool      Https_Get();
+
           void      Trace_TimeSection_OnlyFirstOccurrence_Set (bool Value);
           bool      Trace_TimeSection_OnlyFirstOccurrence_Get ();
 
@@ -109,6 +120,7 @@ public :
               Trace_Format_Tree,
               Trace_Format_CSV,
               Trace_Format_XML,
+              Trace_Format_MICRO_XML,
           };
           void      Trace_Format_Set (trace_Format NewValue);
           trace_Format Trace_Format_Get ();
@@ -146,6 +158,7 @@ public :
           void      Language_Set (const ZtringListList &NewLanguage);
           Ztring    Language_Get ();
           Ztring    Language_Get (const Ztring &Value);
+          Ztring    Language_Get_Translate(const Ztring &Par, const Ztring &Value);
           Ztring    Language_Get (const Ztring &Count, const Ztring &Value, bool ValueIsAlwaysSame=false);
 
           void      Inform_Set (const ZtringListList &NewInform);
@@ -175,6 +188,7 @@ public :
     const ZtringListList &Info_Get(stream_t KindOfStream); //Should not be, but too difficult to hide it
 
           Ztring    Info_Parameters_Get (bool Complete=false);
+          Ztring    Info_OutputFormats_Get(basicformat Format);
           Ztring    Info_Tags_Get       () const;
           Ztring    Info_CodecsID_Get   ();
           Ztring    Info_Codecs_Get     ();
@@ -204,6 +218,8 @@ public :
           int64u    MpegTs_MaximumScanDuration_Get ();
           void      MpegTs_ForceStreamDisplay_Set (bool Value);
           bool      MpegTs_ForceStreamDisplay_Get ();
+          void      MpegTs_ForceTextStreamDisplay_Set(bool Value);
+          bool      MpegTs_ForceTextStreamDisplay_Get();
     #if MEDIAINFO_ADVANCED
           void      MpegTs_VbrDetection_Delta_Set (float64 Value);
           float64   MpegTs_VbrDetection_Delta_Get ();
@@ -218,6 +234,16 @@ public :
           Ztring      MAXML_Fields_Get (const Ztring &StreamKind);
     #endif //MEDIAINFO_ADVANCED
 
+    #if MEDIAINFO_ADVANCED
+          void        Format_Profile_Split_Set (bool Value);
+          bool        Format_Profile_Split_Get ();
+    #endif //MEDIAINFO_ADVANCED
+
+    #if defined(MEDIAINFO_EBUCORE_YES)
+          void        AcquisitionDataOutputMode_Set (size_t Value);
+          size_t      AcquisitionDataOutputMode_Get ();
+    #endif //MEDIAINFO_EBUCORE_YES
+
     ZtringListList  SubFile_Config_Get ();
 
     void            CustomMapping_Set (const Ztring &Value);
@@ -241,6 +267,15 @@ public :
     #endif //MEDIAINFO_EVENTS
 
     #if defined(MEDIAINFO_LIBCURL_YES)
+          bool      CanHandleUrls();
+          enum urlencode
+          {
+              URLEncode_No,
+              URLEncode_Guess,
+              URLEncode_Yes,
+          };
+          void      URLEncode_Set(urlencode NewValue);
+          urlencode URLEncode_Get();
           void      Ssh_PublicKeyFileName_Set (const Ztring &NewValue);
           Ztring    Ssh_PublicKeyFileName_Get ();
           void      Ssh_PrivateKeyFileName_Set (const Ztring &NewValue);
@@ -266,6 +301,10 @@ public :
           void      Ssl_IgnoreSecurity_Set (bool NewValue);
           bool      Ssl_IgnoreSecurity_Get ();
     #endif //defined(MEDIAINFO_LIBCURL_YES)
+    #if MEDIAINFO_FIXITY
+          void      TryToFix_Set (bool NewValue);
+          bool      TryToFix_Get ();
+    #endif //MEDIAINFO_FIXITY
 
 private :
     int64u          FormatDetection_MaximumOffset;
@@ -278,11 +317,18 @@ private :
     int64u          MpegTs_MaximumOffset;
     int64u          MpegTs_MaximumScanDuration;
     bool            MpegTs_ForceStreamDisplay;
+    bool            MpegTs_ForceTextStreamDisplay;
     #if MEDIAINFO_ADVANCED
         float64     MpegTs_VbrDetection_Delta;
         int64u      MpegTs_VbrDetection_Occurences;
         bool        MpegTs_VbrDetection_GiveUp;
     #endif //MEDIAINFO_ADVANCED
+    #if MEDIAINFO_ADVANCED
+        bool        Format_Profile_Split;
+    #endif //MEDIAINFO_ADVANCED
+    #if defined(MEDIAINFO_EBUCORE_YES)
+        size_t      AcquisitionDataOutputMode;
+    #endif //defined(MEDIAINFO_EBUCORE_YES)
     size_t          Complete;
     size_t          BlockMethod;
     size_t          Internet;
@@ -297,6 +343,7 @@ private :
     float32         Verbosity;
     float32         Trace_Level;
     int64u          Compat;
+    bool            Https;
     bool            Trace_TimeSection_OnlyFirstOccurrence;
     std::bitset<32> Trace_Layers; //0-7: Container, 8: Stream
     std::map<Ztring, bool> Trace_Modificators; //If we want to add/remove some details
@@ -342,6 +389,7 @@ private :
     #endif //MEDIAINFO_EVENTS
 
     #if defined(MEDIAINFO_LIBCURL_YES)
+          urlencode URLEncode;
           Ztring    Ssh_PublicKeyFileName;
           Ztring    Ssh_PrivateKeyFileName;
           Ztring    Ssh_KnownHostsFileName;
@@ -356,6 +404,10 @@ private :
           bool      Ssl_IgnoreSecurity;
     #endif //defined(MEDIAINFO_LIBCURL_YES)
 
+    #if MEDIAINFO_FIXITY
+        bool        TryToFix;
+    #endif //MEDIAINFO_SEEK
+
     //Constructor
     MediaInfo_Config (const MediaInfo_Config&);             // Prevent copy-construction
     MediaInfo_Config& operator=(const MediaInfo_Config&);   // Prevent assignment
