@@ -24,7 +24,9 @@
 #include "MediaInfo/Multiple/File_Bdmv.h"
 #include "MediaInfo/MediaInfo.h"
 #include "MediaInfo/MediaInfo_Internal.h"
+#if defined(MEDIAINFO_DIRECTORY_YES)
 #include "ZenLib/Dir.h"
+#endif //defined(MEDIAINFO_DIRECTORY_YES)
 #include "ZenLib/FileName.h"
 using namespace ZenLib;
 //---------------------------------------------------------------------------
@@ -60,7 +62,7 @@ namespace Elements
 //***************************************************************************
 
 //---------------------------------------------------------------------------
-const char* Clpi_Offsets[]=
+static const char* Clpi_Offsets[]=
 {
     "ClipInfo",
     "SequenceInfo",
@@ -74,7 +76,7 @@ const char* Clpi_Offsets[]=
 };
 
 //---------------------------------------------------------------------------
-const char* Indx_Offsets[]=
+static const char* Indx_Offsets[]=
 {
     "AppInfoBDMV",
     "Indexes",
@@ -88,7 +90,7 @@ const char* Indx_Offsets[]=
 };
 
 //---------------------------------------------------------------------------
-const char* Mobj_Offsets[]=
+static const char* Mobj_Offsets[]=
 {
     "MovieObjects",
     "Reserved",
@@ -102,7 +104,7 @@ const char* Mobj_Offsets[]=
 };
 
 //---------------------------------------------------------------------------
-const char* Mpls_Offsets[]=
+static const char* Mpls_Offsets[]=
 {
     "AppInfoPlayList",
     "PlayList",
@@ -116,7 +118,7 @@ const char* Mpls_Offsets[]=
 };
 
 //---------------------------------------------------------------------------
-const char* Bdmv_Type(int32u Type_Indicator, size_t Start_Adress_Pos)
+static const char* Bdmv_Type(int32u Type_Indicator, size_t Start_Adress_Pos)
 {
     switch (Type_Indicator)
     {
@@ -129,7 +131,7 @@ const char* Bdmv_Type(int32u Type_Indicator, size_t Start_Adress_Pos)
 }
 
 //---------------------------------------------------------------------------
-const char* Clpi_Format(int8u StreamType)
+static const char* Clpi_Format(int8u StreamType)
 {
     switch (StreamType)
     {
@@ -157,7 +159,7 @@ const char* Clpi_Format(int8u StreamType)
 }
 
 //---------------------------------------------------------------------------
-const char* Clpi_Format_Profile(int8u StreamType)
+static const char* Clpi_Format_Profile(int8u StreamType)
 {
     switch (StreamType)
     {
@@ -169,7 +171,7 @@ const char* Clpi_Format_Profile(int8u StreamType)
 }
 
 //---------------------------------------------------------------------------
-stream_t Clpi_Type(int8u StreamType)
+static stream_t Clpi_Type(int8u StreamType)
 {
     switch (StreamType)
     {
@@ -197,7 +199,7 @@ stream_t Clpi_Type(int8u StreamType)
 }
 
 //---------------------------------------------------------------------------
-const char* Clpi_Video_Format[]=
+static const char* Clpi_Video_Format[]=
 {
     "",
     "480i",
@@ -218,7 +220,7 @@ const char* Clpi_Video_Format[]=
 };
 
 //---------------------------------------------------------------------------
-const char* Clpi_Video_Interlacement[]=
+static const char* Clpi_Video_Interlacement[]=
 {
     "",
     "Interlaced",
@@ -239,7 +241,7 @@ const char* Clpi_Video_Interlacement[]=
 };
 
 //---------------------------------------------------------------------------
-const char* Clpi_Video_Standard[]=
+static const char* Clpi_Video_Standard[]=
 {
     "",
     "NTSC",
@@ -260,7 +262,7 @@ const char* Clpi_Video_Standard[]=
 };
 
 //---------------------------------------------------------------------------
-int16u Clpi_Video_Width[]=
+static const int16u Clpi_Video_Width[]=
 {
     0,
     720,
@@ -281,7 +283,7 @@ int16u Clpi_Video_Width[]=
 };
 
 //---------------------------------------------------------------------------
-int16u Clpi_Video_Height[]=
+static const int16u Clpi_Video_Height[]=
 {
     0,
     480,
@@ -302,7 +304,7 @@ int16u Clpi_Video_Height[]=
 };
 
 //---------------------------------------------------------------------------
-float32 Clpi_Video_FrameRate[]=
+static const float32 Clpi_Video_FrameRate[]=
 {
     (float32) 0.000,
     (float32)23.976,
@@ -323,7 +325,7 @@ float32 Clpi_Video_FrameRate[]=
 };
 
 //---------------------------------------------------------------------------
-float32 Clpi_Video_AspectRatio[]=
+static const float32 Clpi_Video_AspectRatio[]=
 {
     (float32)0.000,
     (float32)0.000,
@@ -344,7 +346,7 @@ float32 Clpi_Video_AspectRatio[]=
 };
 
 //---------------------------------------------------------------------------
-int8u Clpi_Audio_Channels[]=
+static const int8u Clpi_Audio_Channels[]=
 {
     0,
     1,
@@ -365,7 +367,7 @@ int8u Clpi_Audio_Channels[]=
 };
 
 //---------------------------------------------------------------------------
-int32u Clpi_Audio_SamplingRate[]=
+static const int32u Clpi_Audio_SamplingRate[]=
 {
         0,
     48000,
@@ -386,7 +388,7 @@ int32u Clpi_Audio_SamplingRate[]=
 };
 
 //---------------------------------------------------------------------------
-const char* Indx_object_type[]=
+static const char* Indx_object_type[]=
 {
     "",
     "HDMV",
@@ -395,7 +397,7 @@ const char* Indx_object_type[]=
 };
 
 //---------------------------------------------------------------------------
-const char* Indx_playback_type[4][4]=
+static const char* Indx_playback_type[4][4]=
 {
     {"",            "",             "",             "",             },
     {"Movie",       "Interactive",  "",             "",             },
@@ -404,7 +406,7 @@ const char* Indx_playback_type[4][4]=
 };
 
 //---------------------------------------------------------------------------
-const char* Indx_title_search[]=
+static const char* Indx_title_search[]=
 {
     "Permitted",
     "Prohibited1",
@@ -413,7 +415,7 @@ const char* Indx_title_search[]=
 };
 
 //---------------------------------------------------------------------------
-const char* Mpls_playback_type[]=
+static const char* Mpls_playback_type[]=
 {
     "Sequential",
     "Random",
@@ -422,7 +424,7 @@ const char* Mpls_playback_type[]=
 };
 
 //---------------------------------------------------------------------------
-const char* Mpls_PlayListMarks_Mark_type(int8u type)
+static const char* Mpls_PlayListMarks_Mark_type(int8u type)
 {
     switch (type)
     {
@@ -437,14 +439,9 @@ const char* Mpls_PlayListMarks_Mark_type(int8u type)
 //***************************************************************************
 
 //---------------------------------------------------------------------------
-Ztring Bdmv_Decimal_Hexa(int64u Number)
+static Ztring Bdmv_Decimal_Hexa(int64u Number)
 {
-    Ztring Temp;
-    Temp.From_Number(Number);
-    Temp+=__T(" (0x");
-    Temp+=Ztring::ToZtring(Number, 16);
-    Temp+=__T(")");
-    return Temp;
+    return Get_Hex_ID(Number);
 }
 
 //***************************************************************************
@@ -522,7 +519,7 @@ void File_Bdmv::Read_Buffer_Continue()
         }
     FILLING_END();
 
-    if (version_numberH==0x3031 || version_numberH==0x3032) //Version 1 or 2
+    if (version_numberH==0x3031 || version_numberH==0x3032 || version_numberH==0x3033) //Version 1, 2 or 3 (3 = UHD Blu-ray)
     {
         Element_Begin1("Offsets");
         Types[0x28]=0; //First object
@@ -607,6 +604,7 @@ void File_Bdmv::BDMV()
     Accept("BDMV");
 
     //Searching the longest playlist
+    #if defined(MEDIAINFO_DIRECTORY_YES)
     ZtringList List=Dir::GetAllFileNames(File_Name+PathSeparator+__T("PLAYLIST")+PathSeparator+__T("*.mpls"), Dir::Include_Files);
     std::vector<MediaInfo_Internal*> MIs;
     MIs.resize(List.size());
@@ -660,6 +658,7 @@ void File_Bdmv::BDMV()
         Fill(Stream_General, 0, General_Format_Profile, "BD+");
     if (Dir::Exists(File_Name+PathSeparator+__T("BDJO")) && !Dir::GetAllFileNames(File_Name+PathSeparator+__T("BDJO")).empty())
         Fill(Stream_General, 0, General_Format_Profile, "BD-Java");
+    #endif //defined(MEDIAINFO_DIRECTORY_YES)
 
     //Filling
     File_Name.resize(File_Name.size()-5); //Removing "/BDMV"
