@@ -47,21 +47,6 @@ static const char*  Dv_sct[]=
     "",
 };
 
-//---------------------------------------------------------------------------
-static const char* Dv_Ssyb_Pc0(int8u Pc0)
-{
-    switch (Pc0)
-    {
-        case 0x13 : return "Timecode";
-        case 0x14 : return "Binary group";
-        case 0x50 :
-        case 0x60 : return "Source";
-        case 0x51 :
-        case 0x61 : return "Source control";
-        default   : return "";
-    }
-}
-
 //---------------------------------------------------------------------------
 static const char*  Dv_Disp[]=
 {
@@ -1641,9 +1626,7 @@ void File_DvDif::video_recdate()
 
     Element_Name("video_recdate");
 
-    Ztring Date=recdate();
-    if (Recorded_Date_Date.empty())
-        Recorded_Date_Date=Date;
+    recdate(true);
 }
 
 //---------------------------------------------------------------------------
@@ -1657,9 +1640,7 @@ void File_DvDif::video_rectime()
 
     Element_Name("video_rectime");
 
-    Ztring Date=rectime();
-    if (Recorded_Date_Time.empty())
-        Recorded_Date_Time=Date;
+    rectime(true);
 }
 
 //---------------------------------------------------------------------------
@@ -1716,7 +1697,7 @@ void File_DvDif::consumer_camera_1()
         if (ae_mode<0x0F) Encoded_Library_Settings+=__T("ae mode=")+Ztring(Dv_consumer_camera_1_ae_mode[ae_mode])+__T(" / ");
         if (wb_mode<0x08) Encoded_Library_Settings+=__T("wb mode=")+Ztring(Dv_consumer_camera_1_wb_mode[wb_mode])+__T(" / ");
         if (wb_mode<0x1F) Encoded_Library_Settings+=__T("white balance=")+Ztring(Dv_consumer_camera_1_white_balance(white_balance))+__T(" / ");
-                          Encoded_Library_Settings+=__T("fcm=")+Ztring(Dv_consumer_camera_1_fcm[fcm]);
+        Encoded_Library_Settings+=__T("fcm=")+Ztring(Dv_consumer_camera_1_fcm[fcm]);
     }
 }
 
@@ -1746,7 +1727,7 @@ void File_DvDif::consumer_camera_2()
 //***************************************************************************
 
 //---------------------------------------------------------------------------
-Ztring File_DvDif::recdate()
+void File_DvDif::recdate(bool FromVideo)
 {
     BS_Begin();
 
@@ -1776,26 +1757,27 @@ Ztring File_DvDif::recdate()
 
     BS_End();
 
-    if (Month>12 || Day>31)
-        return Ztring(); //If all bits are set to 1, this is invalid
-    Ztring MonthString;
-    if (Month<10)
-        MonthString=__T("0");
-    MonthString+=Ztring::ToZtring(Month);
-    Ztring DayString;
-    if (Day<10)
-        DayString=__T("0");
-    DayString+=Ztring::ToZtring(Day);
-    return Ztring::ToZtring(Year)+__T("-")+MonthString+__T("-")+DayString;
+    if (FromVideo && Frame_Count==1 && Month<=12 && Day<=31 && Recorded_Date_Date.empty())
+    {
+        Ztring MonthString;
+        if (Month<10)
+            MonthString.assign(1, __T('0'));
+        MonthString+=Ztring::ToZtring(Month);
+        Ztring DayString;
+        if (Day<10)
+            DayString.assign(1, __T('0'));
+        DayString+=Ztring::ToZtring(Day);
+        Recorded_Date_Date=Ztring::ToZtring(Year)+__T('-')+MonthString+__T('-')+DayString;
+    }
 }
 
 //---------------------------------------------------------------------------
-Ztring File_DvDif::rectime()
+void File_DvDif::rectime(bool FromVideo)
 {
     if (!DSF_IsValid)
     {
         Trusted_IsNot("Not in right order");
-        return Ztring();
+        return;
     }
 
     BS_Begin();
@@ -1807,7 +1789,7 @@ Ztring File_DvDif::rectime()
     )
     {
         Skip_XX(4,                                              "All zero");
-        return Ztring();
+        return;
     }
 
     int8u Temp;
@@ -1841,10 +1823,8 @@ Ztring File_DvDif::rectime()
 
     BS_End();
 
-    if (Time!=167185000)
-        return Ztring().Duration_From_Milliseconds(Time);
-    else
-        return Ztring(); //If all bits are set to 1, this is invalid
+    if (FromVideo && Frame_Count==1 && Time!=167185000 && Recorded_Date_Time.empty()) //If all bits are set to 1, this is invalid
+        Recorded_Date_Time.Duration_From_Milliseconds(Time);
 }
 
 } //NameSpace
