@@ -1,20 +1,9 @@
-// File_Gxf - Info for GXF (SMPTE 360M) files
-// Copyright (C) 2010-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // Information about GXF files
@@ -34,7 +23,6 @@
     #include <MediaInfo/Multiple/File_Ancillary.h>
 #endif //defined(MEDIAINFO_ANCILLARY_YES)
 #include "MediaInfo/TimeCode.h"
-#include <map>
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -50,9 +38,12 @@ public :
     //In
     int32u FrameRate_Code;
     int32u FieldsPerFrame_Code;
+    bool   IsAtc; // SMPTE ST 12-2
 
     //Out
-    int64u TimeCode_First;
+    int64u TimeCode_FirstFrame_ms;
+    string TimeCode_FirstFrame;
+    string Settings;
 
     //Constructor/Destructor
     File_Gxf_TimeCode();
