@@ -431,7 +431,7 @@ void File_Ibi::Stream_ByteOffset()
         #if MEDIAINFO_IBIUSAGE
         Param_Info1(Pos);
         #endif //MEDIAINFO_IBIUSAGE
-        Param_Info1(Ztring::ToZtring(Offset)+__T(" (0x")+Ztring::ToZtring(Offset, 16)+__T(')'));
+        Param_Info1(Get_Hex_ID(Offset));
 
         #if MEDIAINFO_IBIUSAGE
         FILLING_BEGIN();
@@ -470,7 +470,7 @@ void File_Ibi::Stream_FrameNumber()
         #if MEDIAINFO_IBIUSAGE
         Param_Info1(Pos);
         #endif //MEDIAINFO_IBIUSAGE
-        Param_Info1(Ztring::ToZtring(Offset)+__T(" (0x")+Ztring::ToZtring(Offset, 16)+__T(')'));
+        Param_Info1(Get_Hex_ID(Offset));
 
         #if MEDIAINFO_IBIUSAGE
         FILLING_BEGIN();
@@ -531,7 +531,7 @@ void File_Ibi::Stream_Dts()
         #if MEDIAINFO_IBIUSAGE
         Param_Info1(Pos);
         #endif //MEDIAINFO_IBIUSAGE
-        Param_Info1(Ztring::ToZtring(Offset)+__T(" (0x")+Ztring::ToZtring(Offset, 16)+__T(')'));
+        Param_Info1(Get_Hex_ID(Offset));
 
         #if MEDIAINFO_IBIUSAGE
         FILLING_BEGIN();
@@ -568,19 +568,17 @@ void File_Ibi::CompressedIndex()
     //Sizes
     unsigned long Source_Size=(unsigned long)(Element_Size-Element_Offset);
     unsigned long Dest_Size=(unsigned long)UncompressedSize;
+    if (Dest_Size>=64*1024*1024)
+    {
+        Reject("Ibi");
+        return;
+    }
 
     //Uncompressing
     int8u* Dest;
-    try
     {
         Dest=new int8u[Dest_Size];
     }
-    catch (...)
-    {
-        //Memory error
-        Reject();
-        return;
-    }
     if (uncompress((Bytef*)Dest, &Dest_Size, (const Bytef*)Buffer+Buffer_Offset+(size_t)Element_Offset, Source_Size)<0)
     {
         Skip_XX(Element_Size-Element_Offset,                    "Problem during the decompression");
@@ -754,8 +752,7 @@ void File_Ibi::InformData()
             }
 
             Fill(StreamKind_Last, StreamPos_Last, Fields[Pos][0].To_UTF8().c_str(), Fields[Pos][1], true);
-            if (Info_Options<Fields[Pos].size())
-                (*Stream_More)[StreamKind_Last][StreamPos_Last](Fields[Pos][0].To_UTF8().c_str(), Info_Options)=Fields[Pos][Info_Options];
+            Fill_SetOptions(StreamKind_Last, StreamPos_Last, Fields[Pos][0].To_UTF8().c_str(), Fields[Pos][Info_Options].To_UTF8().c_str());
         }
     }
     #endif //MEDIAINFO_IBIUSAGE
