@@ -25,8 +25,10 @@
 #include <cstring>
 #include <ctime>
 #include <zlib.h>
-#include "base64.h"
+#include "ThirdParty/base64/base64.h"
+#if defined(MEDIAINFO_REFERENCES_YES)
 #include "ZenLib/File.h"
+#endif //defined(MEDIAINFO_REFERENCES_YES)
 #include "ZenLib/OS_Utils.h"
 #ifdef WINDOWS
     #undef __TEXT
