@@ -17,6 +17,7 @@
 
 //---------------------------------------------------------------------------
 #include "MediaInfo/File__Analyze.h"
+#include "MediaInfo/File__HasReferences.h"
 #if defined(MEDIAINFO_ANCILLARY_YES)
     #include <MediaInfo/Multiple/File_Ancillary.h>
 #endif //defined(MEDIAINFO_ANCILLARY_YES)
@@ -30,13 +31,11 @@
 namespace MediaInfoLib
 {
 
-class File__ReferenceFilesHelper;
-
 //***************************************************************************
 // Class File_Mxf
 //***************************************************************************
 
-class File_Mxf : public File__Analyze
+class File_Mxf : public File__Analyze, File__HasReferences
 {
 public :
     //Constructor/Destructor
@@ -90,7 +89,11 @@ protected :
     //Buffer - Global
     void Read_Buffer_Init ();
     void Read_Buffer_Continue ();
+    #if defined(MEDIAINFO_FILE_YES)
     void Read_Buffer_CheckFileModifications();
+    #else //defined(MEDIAINFO_FILE_YES)
+    void Read_Buffer_CheckFileModifications() {}
+    #endif //defined(MEDIAINFO_FILE_YES)
     void Read_Buffer_AfterParsing ();
     void Read_Buffer_Unsynched();
     #if MEDIAINFO_SEEK
@@ -559,7 +562,7 @@ protected :
     void Info_UL_01xx01_Items () {Element_Offset+=8;};
     void Info_UL_02xx01_Groups () {Element_Offset+=8;};
     void Info_UL_040101_Values () {Element_Offset+=8;};
-    #define Info_UL(_INFO, _NAME, _PARAM) int128u _INFO;
+    #define Info_UL(_INFO, _NAME, _PARAM) Skip_UL(_NAME)
     #endif //MEDIAINFO_TRACE
 
     //TimeCode
@@ -891,6 +894,10 @@ protected :
             //AudioChannelLabelSubDescriptor specific
             SoundfieldGroupLinkID.hi=(int64u)-1;
             SoundfieldGroupLinkID.lo=(int64u)-1;
+        }
+		bool Is_Interlaced() const
+        {
+            return ScanType==__T("Interlaced");
         }
     };
     typedef std::map<int128u, descriptor> descriptors; //Key is InstanceUID of Descriptor
@@ -920,7 +927,6 @@ protected :
     };
     typedef std::map<int128u, locator> locators; //Key is InstanceUID of the locator
     locators Locators;
-    File__ReferenceFilesHelper* ReferenceFiles;
     #if MEDIAINFO_NEXTPACKET
         bool                    ReferenceFiles_IsParsing;
     #endif //MEDIAINFO_NEXTPACKET
@@ -1140,6 +1146,7 @@ protected :
     void           ChooseParser_Jpeg2000(const essences::iterator &Essence, const descriptors::iterator &Descriptor);
 
     //Helpers
+    int32u Vector(int32u ExpectedLength=(int32u)-1);
     void Subsampling_Compute(descriptors::iterator Descriptor);
     #if defined(MEDIAINFO_REFERENCES_YES)
         void Locators_CleanUp();
@@ -1248,6 +1255,15 @@ protected :
             : Value(Value_)
             , FrameCount(1)
         {}
+        bool Add(const string& Value_)
+        {
+            if (Value == Value_)
+            {
+                FrameCount++;
+                return true;
+            }
+            return false;
+        }
     };
     typedef std::vector<acquisitionmetadata> acquisitionmetadatalist;
     vector<acquisitionmetadatalist*> AcquisitionMetadataLists;
@@ -1259,9 +1275,8 @@ protected :
             AcquisitionMetadataLists[Id]->push_back(acquisitionmetadata(Value));
             return;
         }
-        if ((*AcquisitionMetadataLists[Id])[AcquisitionMetadataLists[Id]->size()-1].Value == Value)
+        if ((*AcquisitionMetadataLists[Id])[AcquisitionMetadataLists[Id]->size()-1].Add(Value))
         {
-            (*AcquisitionMetadataLists[Id])[AcquisitionMetadataLists[Id]->size()-1].FrameCount++;
             return;
         }
         AcquisitionMetadataLists[Id]->push_back(acquisitionmetadata(Value));
@@ -1275,9 +1290,8 @@ protected :
             AcquisitionMetadata_Sony_E201_Lists[Id]->push_back(acquisitionmetadata(Value));
             return;
         }
-        if ((*AcquisitionMetadata_Sony_E201_Lists[Id])[AcquisitionMetadata_Sony_E201_Lists[Id]->size()-1].Value == Value)
+        if ((*AcquisitionMetadata_Sony_E201_Lists[Id])[AcquisitionMetadata_Sony_E201_Lists[Id]->size()-1].Add(Value))
         {
-            (*AcquisitionMetadata_Sony_E201_Lists[Id])[AcquisitionMetadata_Sony_E201_Lists[Id]->size()-1].FrameCount++;
             return;
         }
         AcquisitionMetadata_Sony_E201_Lists[Id]->push_back(acquisitionmetadata(Value));
@@ -1334,7 +1348,11 @@ protected :
         int128u Clip_Code;
         int64u  OverallBitrate_IsCbrForSure;
         bool    Duration_Detected;
+        #if defined(MEDIAINFO_FILE_YES)
         bool    DetectDuration();
+        #else //defined(MEDIAINFO_FILE_YES)
+        bool    DetectDuration() { return false; }
+        #endif //defined(MEDIAINFO_FILE_YES)
         int64u  DemuxedSampleCount_Total;
         int64u  DemuxedSampleCount_Current;
         int64u  DemuxedSampleCount_AddedToFirstFrame;
