@@ -40,7 +40,9 @@
 #if MEDIAINFO_EVENTS
     #include "MediaInfo/MediaInfo_Events.h"
 #endif //MEDIAINFO_EVENTS
+#if defined(MEDIAINFO_FILE_YES)
 #include <ZenLib/File.h>
+#endif //defined(MEDIAINFO_FILE_YES)
 #include <ZenLib/Utils.h>
 using namespace ZenLib;
 //---------------------------------------------------------------------------
@@ -869,6 +871,7 @@ void File_Riff::Header_Parse()
         {
             if (File_Offset+Buffer_Offset+8+Size==File_Size)
                 IsNotWordAligned=true;
+            #if defined(MEDIAINFO_FILE_YES) //TODO: seek if file API is not available
             else if (!File_Name.empty())
             {
                 File F(File_Name);
@@ -880,6 +883,7 @@ void File_Riff::Header_Parse()
                         IsNotWordAligned=true;
                 }
             }
+            #endif //defined(MEDIAINFO_FILE_YES)
             IsNotWordAligned_Tested=true;
         }
     }
@@ -914,7 +918,11 @@ void File_Riff::Header_Parse()
         Size_Complete=0; //Hack in some indexes with Size==0 (why?), ignoring content of header
     }
     if (File_Offset+Buffer_Offset+8+Size_Complete>File_Size)
+    {
         Size_Complete=File_Size-(File_Offset+Buffer_Offset+8);
+        if (Element_Level<=2) //Incoherencies info only at the top level chunk
+            Fill(Stream_General, 0, "IsTruncated", "Yes");
+    }
 
     //Alignment
     if (Size_Complete%2 && !IsNotWordAligned)
@@ -975,7 +983,7 @@ void File_Riff::Header_Parse()
             Buffer_DataToParse_End=File_Offset+Buffer_Offset+8+Size_Complete;
         else
             Buffer_DataToParse_End=File_Size; //Found one file with 0 as size of data part
-        Size_Complete=0;
+        Size_Complete=(Name==Elements::AIFF_SSND?8:0);
     }
 
     //Filling
