@@ -17,6 +17,7 @@
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
+#if defined(MEDIAINFO_FILE_YES)
 #include "MediaInfo/Reader/Reader__Base.h"
 #include "ZenLib/File.h"
 #include "ZenLib/Thread.h"
@@ -42,6 +43,7 @@ class Reader_File_Thread : public Thread
 {
 public:
     Reader_File* Base;
+    size_t ReadSize_Max;
     void Entry();
 };
 #endif //MEDIAINFO_READTHREAD
@@ -62,6 +64,7 @@ public :
     std::bitset<32> Status;
     int64u          Partial_Begin;
     int64u          Partial_End;
+    size_t          CountOfSeconds;
 
     //Thread
     #if MEDIAINFO_READTHREAD
@@ -82,4 +85,6 @@ public :
 };
 
 } //NameSpace
+#endif //defined(MEDIAINFO_FILE_YES)
+
 #endif
