@@ -17,7 +17,7 @@
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
-#if defined(MEDIAINFO_VORBISCOM_YES) || defined(MEDIAINFO_OGG_YES)
+#if defined(MEDIAINFO_VORBISCOM_YES)
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
