@@ -95,14 +95,14 @@ void File_Eia708::Streams_Fill()
             Stream_Prepare(Stream_Text);
             Fill(Stream_Text, StreamPos_Last, Text_ID, Pos);
             Fill(Stream_Text, StreamPos_Last, "CaptionServiceName", Pos);
-            (*Stream_More)[StreamKind_Last][StreamPos_Last](Ztring().From_Local("CaptionServiceName"), Info_Options)=__T("N NT");
+            Fill_SetOptions(StreamKind_Last, StreamPos_Last, "CaptionServiceName", "N NT");
             Fill(Stream_Text, StreamPos_Last, Text_Format, "EIA-708");
             Fill(Stream_Text, StreamPos_Last, Text_StreamSize, 0);
             Fill(Stream_Text, StreamPos_Last, Text_BitRate_Mode, "CBR");
             if (Config->ParseSpeed>=1.0)
             {
                 Fill(Stream_Text, StreamPos_Last, "CaptionServiceContent_IsPresent", (DataDetected&((int64u)1)<<Pos)?"Yes":"No", Unlimited, true, true); //1 bit per service
-                (*Stream_More)[Stream_Text][StreamPos_Last](Ztring().From_Local("CaptionServiceContent_IsPresent"), Info_Options)=__T("N NT");
+                Fill_SetOptions(Stream_Text, StreamPos_Last, "CaptionServiceContent_IsPresent", "N NT");
             }
             if (ServiceDescriptors)
             {
@@ -111,12 +111,12 @@ void File_Eia708::Streams_Fill()
                 {
                     Fill(Stream_Text, StreamPos_Last, Text_Language, ServiceDescriptor->second.language, true);
                     Fill(Stream_Text, StreamPos_Last, "CaptionServiceDescriptor_IsPresent", "Yes", Unlimited, true, true);
-                    (*Stream_More)[Stream_Text][StreamPos_Last](Ztring().From_Local("CaptionServiceDescriptor_IsPresent"), Info_Options)=__T("N NT");
+                    Fill_SetOptions(Stream_Text, StreamPos_Last, "CaptionServiceDescriptor_IsPresent", "N NT");
                 }
                 else //ServiceDescriptors pointer is for the support by the transport layer of the info
                 {
                     Fill(Stream_Text, StreamPos_Last, "CaptionServiceDescriptor_IsPresent", "No", Unlimited, true, true);
-                    (*Stream_More)[Stream_Text][StreamPos_Last](Ztring().From_Local("CaptionServiceDescriptor_IsPresent"), Info_Options)=__T("N NT");
+                    Fill_SetOptions(Stream_Text, StreamPos_Last, "CaptionServiceDescriptor_IsPresent", "N NT");
                 }
             }
         }
@@ -752,7 +752,7 @@ void File_Eia708::CR()
     int8u y=Window->Minimal.y;
 
     y++;
-    if (y>=Window->row_count)
+    if (y>=Window->row_count-1)
     {
         //Rolling up window
         for (int8u Pos_Y=0; Pos_Y<Window->row_count-1; Pos_Y++)
@@ -1512,6 +1512,7 @@ void File_Eia708::HasChanged()
         EVENT_BEGIN (DtvccCaption, Content_Minimal, 0)
             Event.MuxingMode=MuxingMode;
             Event.Service=service_number;
+            Event.StreamIDs[Event.StreamIDs_Size-1]=Event.Service;
             for (size_t Pos_Y=0; Pos_Y<Streams[service_number]->Minimal.CC.size(); Pos_Y++)
             {
                 for (size_t Pos_X=0; Pos_X<Streams[service_number]->Minimal.CC[Pos_Y].size(); Pos_X++)
