@@ -83,36 +83,6 @@ static const string HuffYUV_ColorSpace(bool rgb, bool chroma, bool alpha)
     return ToReturn;
 }
 
-static const char* HuffYUV_method (int16u BitCount, int8u method)
-{
-    switch (BitCount&0x0007)
-    {
-        case 0 :
-                    switch (method)
-                    {
-                        case 0xFE : return "old";
-                        case    0 : return "left";
-                        case    1 : return "gradient";
-                        case    2 : return "median";
-                        case   64 : return "left with decorrelation";
-                        case   65 : return "gradient with decorrelation";
-                        default : return "";
-                    }
-        case 1 :    return "left";
-        case 2 :    return "left with decorrelation";
-        case 3 :
-                    switch (BitCount&0xFFF8)
-                    {
-                        case 16 : return "gradient";
-                        case 24 :
-                        case 32 : return "gradient with decorrelation";
-                        default : return "";
-                    }
-        case 4 :    return "median";
-        default :   return "";
-    }
-}
-
 //***************************************************************************
 // Constructor/Destructor
 //***************************************************************************
@@ -129,7 +99,6 @@ File_HuffYuv::File_HuffYuv()
     IsRawStream=true;
 
     //In
-    IsOutOfBandData=false;
     BitCount=0;
     Height=0;
 }
@@ -149,19 +118,28 @@ void File_HuffYuv::Streams_Accept()
 // Buffer - Global
 //***************************************************************************
 
+//---------------------------------------------------------------------------
+void File_HuffYuv::Read_Buffer_OutOfBand()
+{
+    FrameHeader();
+    if (Element_Offset<Element_Size)
+        Skip_XX(Element_Size-Element_Offset,                    "Unknown");
+
+    FILLING_BEGIN()
+        Accept();
+    FILLING_END();
+}
+
 //---------------------------------------------------------------------------
 void File_HuffYuv::Read_Buffer_Continue()
 {
-    Accept();
+    Skip_XX(Element_Size,                                       "Data");
 
-    if (IsOutOfBandData)
+    if (!Status[IsAccepted]) //No test except that the stream has no out of band data
     {
-        FrameHeader();
-    }
-    else if (Frame_Count==0)
+        Accept();
         Fill(Stream_Video, 0, Video_Format_Version, "Version 1");
-
-    Skip_XX(Element_Size-Element_Offset,                        "Other data");
+    }
 
     Frame_Count++;
     Finish();
