@@ -37,7 +37,6 @@
 #include <clocale>
 using namespace MediaInfoLib;
 using namespace ZenLib;
-using namespace std;
 //---------------------------------------------------------------------------
 
 //***************************************************************************
@@ -54,7 +53,7 @@ typedef std::map<void*, mi_output*> mi_outputs;
 
 struct mi_input
 {
-    Ztring Unicode[8];  //Unicode characters multiple times
+    Ztring Unicode[3];  //Unicode characters multiple times
 };
 typedef std::map<void*, mi_input*> mi_inputs;
 
@@ -65,15 +64,14 @@ static CriticalSection Critical;
 static bool utf8=false;
 
 //---------------------------------------------------------------------------
-const char* WC2MB(void* Handle, const wchar_t* Text)
+static const char* WC2MB(void* Handle, const wchar_t* Text)
 {
     //Coherancy
     Critical.Enter();
     mi_outputs::iterator MI_Output=MI_Outputs.find(Handle);
-    if (MI_Outputs.find(Handle)==MI_Outputs.end())
+    if (MI_Output==MI_Outputs.end())
     {
-        MI_Outputs[Handle]=new mi_output; //Generic Handle
-        MI_Output=MI_Outputs.find(Handle);
+        MI_Output=MI_Outputs.insert(std::make_pair(Handle,new mi_output)).first; //Generic Handle
     }
     Critical.Leave();
 
@@ -86,15 +84,14 @@ const char* WC2MB(void* Handle, const wchar_t* Text)
 }
 
 //---------------------------------------------------------------------------
-const wchar_t* MB2WC(void* Handle, size_t Pos, const char* Text)
+static const wchar_t* MB2WC(void* Handle, size_t Pos, const char* Text)
 {
     //Coherancy
     Critical.Enter();
     mi_inputs::iterator MI_Input=MI_Inputs.find(Handle);
     if (MI_Input==MI_Inputs.end())
     {
-        MI_Inputs[Handle]=new mi_input; //Generic Handle
-        MI_Input=MI_Inputs.find(Handle);
+        MI_Input=MI_Inputs.insert(std::make_pair(Handle, new mi_input)).first;
     }
     Critical.Leave();
 
@@ -225,7 +222,7 @@ const wchar_t* MB2WC(void* Handle, size_t Pos, const char* Text)
     MEDIAINFO_DEBUG1(_NAME,_DEBUGA) \
     Critical.Enter(); \
     mi_outputs::iterator MI_Output=MI_Outputs.find(Handle); \
-    bool MI_Output_IsOk=MI_Outputs.find(Handle)!=MI_Outputs.end(); \
+    const bool MI_Output_IsOk=MI_Output!=MI_Outputs.end(); \
     Critical.Leave(); \
     if (Handle==NULL || !MI_Output_IsOk) \
     { \
@@ -237,7 +234,7 @@ const wchar_t* MB2WC(void* Handle, size_t Pos, const char* Text)
     MEDIAINFO_DEBUG1(_NAME,_DEBUGA) \
     Critical.Enter(); \
     mi_outputs::iterator MI_Output=MI_Outputs.find(Handle); \
-    bool MI_Output_IsOk=MI_Outputs.find(Handle)!=MI_Outputs.end(); \
+    const bool MI_Output_IsOk=MI_Output!=MI_Outputs.end(); \
     Critical.Leave(); \
     if (Handle==NULL || !MI_Output_IsOk) \
     { \
@@ -249,7 +246,7 @@ const wchar_t* MB2WC(void* Handle, size_t Pos, const char* Text)
     MEDIAINFO_DEBUG1(_NAME,_DEBUGA) \
     Critical.Enter(); \
     mi_outputs::iterator MI_Output=MI_Outputs.find(Handle); \
-    bool MI_Output_IsOk=MI_Outputs.find(Handle)!=MI_Outputs.end(); \
+    const bool MI_Output_IsOk=MI_Output!=MI_Outputs.end(); \
     Critical.Leave(); \
     if (Handle==NULL || !MI_Output_IsOk) \
     { \
@@ -261,7 +258,7 @@ const wchar_t* MB2WC(void* Handle, size_t Pos, const char* Text)
     MEDIAINFO_DEBUG1(_NAME,_DEBUGA) \
     Critical.Enter(); \
     mi_outputs::iterator MI_Output=MI_Outputs.find(Handle); \
-    bool MI_Output_IsOk=MI_Outputs.find(Handle)!=MI_Outputs.end(); \
+    const bool MI_Output_IsOk=MI_Output!=MI_Outputs.end(); \
     Critical.Leave(); \
     if (Handle==NULL || !MI_Output_IsOk) \
     { \
